-- *******************************************************
--   KOHA  MARC 21 STANDARD DEFAULT AUTHORITY FRAMEWORKS
--
--        Revised to Update No. 22 (April 2016)
-- *******************************************************

-- ******************************************************
-- KOHA DEFAULT MARC 21 AUTHORITY TYPE.
-- ******************************************************

-- This authority type includes all fields and subfieds used by any
-- authority type.

INSERT INTO auth_types (authtypecode, authtypetext, auth_tag_to_report, summary) VALUES
		('', 'Predeterminado', '', '');


-- ******************************************************
-- KOHA SUPPORTED STANDARD MARC 21 AUTHORITY TYPES.
-- ******************************************************

-- These authority types are supported for for guiding the cataloguer to
-- fill authorised values in Koha MARC bibliographic editor.


INSERT INTO auth_types (authtypecode, authtypetext, auth_tag_to_report, summary) VALUES
		('PERSO_NAME', 'Nombre personal', '100', 'Nombre personal'),
		('CORPO_NAME', 'Nombre corporativo', '110', 'Nombre corporativo'),
		('MEETI_NAME', 'Nombre de reunión', '111', 'Nombre de reunión'),
		('UNIF_TITLE', 'Título uniforme', '130', 'Título uniforme'),
		('CHRON_TERM', 'Término cronológico', '148', 'Término cronológico'),
		('TOPIC_TERM', 'Término temático', '150', 'Término temático'),
		('GEOGR_NAME', 'Nombre geográfico', '151', 'Nombre geográfico'),
		('GENRE/FORM', 'Términos de género/forma', '155', 'Términos de género/forma');


-- ******************************************************
-- KOHA UNSUPPORTED STANDARD MARC 21 AUTHORITY TYPES.
-- ******************************************************

-- These authority types are only supported for guiding the cataloguer to
-- fill authorised values in the Koha MARC bibliographic editor to the
-- extent that they have already been included in a primary authority type,
-- therefore, they have not yet been specified.
--
-- Minimal primary authorities including subdivisions may currently be
-- built by a script which uses the values in bibliographic records but
-- include no tracings and references which are necessarily not present
-- in bibliographic records.


-- INSERT INTO `auth_types` (`authtypecode`, `authtypetext`, `auth_tag_to_report`, `summary`) VALUES
--		('TOPIC_SUBD', 'General Topical Term Subdivision', '180', 'General Topical Term Subdivision'),
--		('GEOGR_SUBD', 'Geographic Subdivision', '181', 'Geographic Subdivision'),
--		('CHRON_SUBD', 'Chronological Subdivision', '182', 'Chronological Subdivision'),
--		('FORM_SUBDI', 'Form Subdivision', '185', 'Form Subdivision');



-- *****************************************************************
-- MARC 21 AUTHORITY FIELDS/SUBFIELDS AND COMMMONLY USED EXTENSIONS
-- *****************************************************************


-- No support for subfield visibility is yet provided by the Koha code
-- matching the column name 'hidden' in the bibliographic framework.
--
-- Needs checking for errors but probably tolerable for use on a production.
-- A server can be upgraded easily from later versions of this file.
--
-- In the absense of more column support for qualifying the relative
-- importance of subfields to the record editor, some modest modification of
-- the default framework is needed setting the not-useful non-Koha holdings
-- subfields to not managed in Koha.

-- MARC fields including letters as part of the field identifier are from RLIN
-- and should be expected to remain along with RLIN $% subfields.  RLIN has
-- been using letters in fields because there are not enough local use number
-- fields which have not already been specified for very large union catalogue
-- networks such as RLIN itself.

-- Fields ending in a or b are temporary placeholders for information from
-- a numeric value until a non-conflicting way to treat the content under the
-- proper original numeric field is adopted.  090 for LC call numbers is much
-- too common and important so 999 is also provided as a temporary place
-- holder until all Koha code for finding control fields has been changed from
-- a numeric test of < 10 to a regular expression match of m/^00/ to prevent
-- mistaken matching of fields with letters such as 09o if they were control
-- fields.

-- Fields and subfields which belong exclusively in a classification
-- framework have been marked '[CLASSIFICATION FRAMEWORK]'.  They are retained
-- or included here becuase some had been included previously and Koha does
-- not yet have a classification framework.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES
		('', '000', 'CABECERA', 'CABECERA', 0, 1, NULL),
		('', '001', 'NÚMERO DE CONTROL', 'NÚMERO DE CONTROL', 0, 1, NULL),
		('', '003', 'IDENTIFICADOR DEL NÚMERO DE CONTROL', 'IDENTIFICADOR DEL NÚMERO DE CONTROL', 0, 1, NULL),
		('', '005', 'FECHA Y HORA DE LA ÚLTIMA TRANSACCIÓN', 'FECHA Y HORA DE LA ÚLTIMA TRANSACCIÓN', 0, 1, NULL),
		('', '008', 'DATOS DE LONGITUD FIJA', 'DATOS DE LONGITUD FIJA', 0, 1, NULL),
		('', '010', 'NÚMERO DE CONTROL DE LA BIBLIOTECA DEL CONGRESO', 'NÚMERO DE CONTROL DE LA BIBLIOTECA DEL CONGRESO', 0, 0, NULL),
		('', '014', 'ENLACE AL REGISTRO BIBLIOGRÁFICO PARA PUBLICACIÓN SERIADA O ÍTEM EN VARIAS PARTES', 'ENLACE AL REGISTRO BIBLIOGRÁFICO PARA PUBLICACIÓN SERIADA O ÍTEM EN VARIAS PARTES', 1, 0, NULL),
		('', '016', 'NÚMERO DE CONTROL DE UNA AGENCIA BIBLIOGRÁFICA NACIONAL', 'NÚMERO DE CONTROL DE UNA AGENCIA BIBLIOGRÁFICA NACIONAL', 1, 0, NULL),
		('', '020', 'NÚMERO INTERNACIONAL ESTÁNDAR DEL LIBRO', 'NÚMERO INTERNACIONAL ESTÁNDAR DEL LIBRO', 1, 0, NULL),
		('', '022', 'NÚMERO INTERNACIONAL NORMALIZADO PARA PUBLICACIONES SERIADAS', 'NÚMERO INTERNACIONAL NORMALIZADO PARA PUBLICACIONES SERIADAS', 1, 0, NULL),
		('', '024', 'IDENTIFICADOR DE OTROS ESTÁNDARES', 'IDENTIFICADOR DE OTROS ESTÁNDARES', 1, 0, NULL),
		('', '031', 'INFORMACIÓN DE LOS ÍNCIPITS MUSICALES', 'INFORMACIÓN DE LOS ÍNCIPITS MUSICALES', 1, 0, NULL),
		('', '034', 'DATOS MATEMÁTICOS CARTOGRÁFICOS CODIFICADOS', 'DATOS MATEMÁTICOS CARTOGRÁFICOS CODIFICADOS', 1, 0, NULL),
		('', '035', 'NÚMERO DE CONTROL DEL SISTEMA', 'NÚMERO DE CONTROL DEL SISTEMA', 1, 0, NULL),
		('', '040', 'FUENTE DE LA CATALOGACIÓN', 'FUENTE DE LA CATALOGACIÓN', 0, 1, NULL),
		('', '042', 'CÓDIGO DE AUTENTICACIÓN', 'CÓDIGO DE AUTENTICACIÓN', 0, 0, NULL),
		('', '043', 'CÓDIGO DE ÁREA GEOGRÁFICA', 'CÓDIGO DE ÁREA GEOGRÁFICA', 0, 0, NULL),
		('', '045', 'PERIODO DE TIEMPO DEL ENCABEZAMIENTO', 'PERIODO DE TIEMPO DEL ENCABEZAMIENTO', 0, 0, NULL),
		('', '046', 'FECHAS CON CODIFICACIÓN ESPECIAL', 'FECHAS CON CODIFICACIÓN ESPECIAL', 1, 0, NULL),
		('', '050', 'SIGNATURA TOPOGRÁFICA DE LA BIBLIOTECA DEL CONGRESO', 'SIGNATURA TOPOGRÁFICA DE LA BIBLIOTECA DEL CONGRESO', 1, 0, NULL),
		('', '052', 'CLASIFICACIÓN GEOGRÁFICA', 'CLASIFICACIÓN GEOGRÁFICA', 1, 0, NULL),
		('', '053', 'NÚMERO DE CLASIFICACIÓN LC', 'NÚMERO DE CLASIFICACIÓN LC', 1, 0, NULL),
		('', '055', 'SIGNATURA TOPOGRÁFICA DE BIBLIOTECAS Y ARCHIVOS DE CANADÁ', 'SIGNATURA TOPOGRÁFICA DE BIBLIOTECAS Y ARCHIVOS DE CANADÁ', 1, 0, NULL),
		('', '058', 'NÚMERO DE CLASIFICACIÓN LC ASIGNADOS EN CANADÁ [OBSOLETO, CAN/MARC]', 'NÚMERO DE CLASIFICACIÓN LC ASIGNADOS EN CANADÁ [OBSOLETO, CAN/MARC]', 1, 0, NULL),
		('', '060', 'SIGNATURA TOPOGRÁFICA DE LA NATIONAL LIBRARY OF MEDICINE', 'SIGNATURA TOPOGRÁFICA DE LA NATIONAL LIBRARY OF MEDICINE', 1, 0, NULL),
		('', '063', 'NÚMERO DE CLASIFICACIÓN NLM ASIGNADO POR NLM [OBSOLETO, CAN/MARC]', 'NÚMERO DE CLASIFICACIÓN NLM ASIGNADO POR NLM [OBSOLETO, CAN/MARC]', 1, 0, NULL),
		('', '065', 'OTRO NÚMERO DE CLASIFICACIÓN', 'OTRO NÚMERO DE CLASIFICACIÓN', 1, 0, NULL),
		('', '066', 'JUEGOS/CONJUNTO DE CARACTERES UTILIZADOS/PRESENTES', 'JUEGOS/CONJUNTO DE CARACTERES UTILIZADOS/PRESENTES', 0, 0, NULL),
		('', '068', 'NÚMERO DE CLASIFICACIÓN NLM ASIGNADO EN CANADÁ [OBSOLETO, CAN/MARC]', 'NÚMERO DE CLASIFICACIÓN NLM ASIGNADO EN CANADÁ [OBSOLETO, CAN/MARC]', 1, 0, NULL),
		('', '070', 'SIGNATURA TOPOGRÁFICA DE LA NATIONAL AGRICULTURAL LIBRARY', 'SIGNATURA TOPOGRÁFICA DE LA NATIONAL AGRICULTURAL LIBRARY', 1, 0, NULL),
		('', '072', 'CÓDIGO DE CATEGORÍA DE MATERIA', 'CÓDIGO DE CATEGORÍA DE MATERIA', 1, 0, NULL),
		('', '073', 'USO DE SUBDIVISIÓN', 'USO DE SUBDIVISIÓN', 0, 0, NULL),
		('', '080', 'NÚMERO DE LA CLASIFICACIÓN DECIMAL UNIVERSAL', 'NÚMERO DE LA CLASIFICACIÓN DECIMAL UNIVERSAL', 1, 0, NULL),
		('', '082', 'SIGNATURA TOPOGRÁFICA DECIMAL DEWEY', 'SIGNATURA TOPOGRÁFICA DECIMAL DEWEY', 1, 0, NULL),
		('', '083', 'NÚMERO DE LA CLASIFICACIÓN DECIMAL DEWEY', 'NÚMERO DE LA CLASIFICACIÓN DECIMAL DEWEY', 1, 0, NULL),
		('', '084', 'ESQUEMA DE CLASIFICACIÓN Y EDICIÓN [FORMATO DE CLASIFICACIÓN]', 'ESQUEMA DE CLASIFICACIÓN Y EDICIÓN [FORMATO DE CLASIFICACIÓN]', 0, 0, NULL),
		('', '086', 'SIGNATURA TOPOGRÁFICA PARA DOCUMENTOS GUBERNAMENTALES', 'SIGNATURA TOPOGRÁFICA PARA DOCUMENTOS GUBERNAMENTALES', 1, 0, NULL),
		('', '087', 'NÚMERO DE CLASIFICACIÓN PARA DOCUMENTOS GUBERNAMENTALES', 'NÚMERO DE CLASIFICACIÓN PARA DOCUMENTOS GUBERNAMENTALES', 1, 0, NULL),
		('', '088', 'NÚMERO DE ESTANTERÍA DEL DOCUMENTO (CODOC) [OBSOLETO, CAN/MARC]', 'NÚMERO DE ESTANTERÍA DEL DOCUMENTO (CODOC) [OBSOLETO, CAN/MARC]', 1, 0, NULL),
		('', '090', 'SIGNATURA TOPOGRÁFICA LOCAL (SERIE) [OBSOLETO]; LOCALMENTE ASIGNADO TIPO-LC SIGNATURA TOPOGRÁFICA (OCLC); SIGNATURA TOPOGRÁFICA LOCAL (RLIN)', 'SIGNATURA TOPOGRÁFICA LOCAL (SERIE) [OBSOLETO]; LOCALMENTE ASIGNADO TIPO-LC SIGNATURA TOPOGRÁFICA (OCLC); SIGNATURA TOPOGRÁFICA LOCAL (RLIN)', 1, 0, NULL),
		('', '091', 'LOCALMENTE ASIGNADO TIPO-LC NÚMERO DE CLASIFICACIÓN (OCLC); NÚMERO DE CLASIFICACIÓN LOCAL (RLIN)', 'LOCALMENTE ASIGNADO TIPO-LC NÚMERO DE CLASIFICACIÓN (OCLC); NÚMERO DE CLASIFICACIÓN LOCAL (RLIN)', 0, 0, NULL),
		('', '092', 'ASIGNACIÓN LOCAL DE SIGNATURA TOPOGRÁFICA DEWEY (OCLC)', 'ASIGNACIÓN LOCAL DE SIGNATURA TOPOGRÁFICA DEWEY (OCLC)', 1, 0, NULL),
		('', '093', 'ASIGNACIÓN LOCAL DEL NÚMERO DE CLASIFICACIÓN DEWEY (OCLC)', 'ASIGNACIÓN LOCAL DEL NÚMERO DE CLASIFICACIÓN DEWEY (OCLC)', 1, 0, NULL),
		('', '096', 'ASIGNACIÓN LOCAL TIPO-NLM SIGNATURA TOPOGRÁFICA (OCLC)', 'ASIGNACIÓN LOCAL TIPO-NLM SIGNATURA TOPOGRÁFICA (OCLC)', 1, 0, NULL),
		('', '097', 'ASIGNACIÓN LOCAL TIPO-NLM NÚMERO DE CLASIFICACIÓN (OCLC)', 'ASIGNACIÓN LOCAL TIPO-NLM NÚMERO DE CLASIFICACIÓN (OCLC)', 1, 0, NULL),
		('', '098', 'OTROS ESQUEMAS DE CLASIFICACIÓN (OCLC)', 'OTROS ESQUEMAS DE CLASIFICACIÓN (OCLC)', 1, 0, NULL),
		('', '099', 'TEXTO-LIBRO SIGNATURA TOPOGRÁFICA LOCAL (OCLC)', 'TEXTO-LIBRO SIGNATURA TOPOGRÁFICA LOCAL (OCLC)', 1, 0, NULL),
		('', '100', 'ENCABEZAMIENTO-NOMBRE DE PERSONA', 'ENCABEZAMIENTO-NOMBRE DE PERSONA', 0, 0, NULL),
		('', '110', 'ENCABEZAMIENTO-NOMBRE DE ENTIDAD CORPORATIVA', 'ENCABEZAMIENTO-NOMBRE DE ENTIDAD CORPORATIVA', 0, 0, NULL),
		('', '111', 'ENCABEZAMIENTO--NOMBRE DE CONGRESO/REUNIÓN', 'ENCABEZAMIENTO--NOMBRE DE CONGRESO/REUNIÓN', 0, 0, NULL),
		('', '130', 'ENCABEZAMIENTO--TÍTULO UNIFORME', 'ENCABEZAMIENTO--TÍTULO UNIFORME', 0, 0, NULL),
		('', '140', 'TÍTULO UNIFORME [OBSOLETO, CAN/MARC]', 'TÍTULO UNIFORME [OBSOLETO, CAN/MARC]', 1, 0, NULL),
		('', '143', 'TÍTULO COLECTIVO [OBSOLETO, CAN/MARC]', 'TÍTULO COLECTIVO [OBSOLETO, CAN/MARC]', 1, 0, NULL),
		('', '148', 'ENCABEZAMIENTO--TÉRMINO CRONOLÓGICO', 'ENCABEZAMIENTO--TÉRMINO CRONOLÓGICO', 0, 0, NULL),
		('', '150', 'ENCABEZAMIENTO--TÉRMINO DE MATERIA', 'ENCABEZAMIENTO--TÉRMINO DE MATERIA', 0, 0, NULL),
		('', '151', 'ENCABEZAMIENTO--NOMBRE GEOGRÁFICO', 'ENCABEZAMIENTO--NOMBRE GEOGRÁFICO', 0, 0, NULL),
		('', '153', 'NÚMERO DE CLASIFICACIÓN [FORMATO DE CLASIFICACIÓN]', 'NÚMERO DE CLASIFICACIÓN [FORMATO DE CLASIFICACIÓN]', 0, 0, NULL),
		('', '154', 'TÉRMINO EXPLICATIVO GENERAL DE ÍNDICE [FORMATO DE CLASIFICACIÓN]', 'TÉRMINO EXPLICATIVO GENERAL DE ÍNDICE [FORMATO DE CLASIFICACIÓN]', 0, 0, NULL),
		('', '155', 'ENCABEZAMIENTO--TÉRMINO DE GÉNERO/FORMA', 'ENCABEZAMIENTO--TÉRMINO DE GÉNERO/FORMA', 0, 0, NULL),
		('', '162', 'ENCABEZAMIENTO-TÉRMINO DE MEDIO DE INTERPRETACIÓN', 'ENCABEZAMIENTO-TÉRMINO DE MEDIO DE INTERPRETACIÓN', 0, 0, NULL),
		('', '180', 'ENCABEZAMIENTO--SUBDIVISIÓN GENERAL', 'ENCABEZAMIENTO--SUBDIVISIÓN GENERAL', 0, 0, NULL),
		('', '181', 'ENCABEZAMIENTO--SUBDIVISIÓN GEOGRÁFICA', 'ENCABEZAMIENTO--SUBDIVISIÓN GEOGRÁFICA', 0, 0, NULL),
		('', '182', 'ENCABEZAMIENTO--SUBDIVISIÓN CRONOLÓGICA', 'ENCABEZAMIENTO--SUBDIVISIÓN CRONOLÓGICA', 0, 0, NULL),
		('', '185', 'ENCABEZAMIENTO--SUBDIVISIÓN DE FORMA', 'ENCABEZAMIENTO--SUBDIVISIÓN DE FORMA', 0, 0, NULL),
		('', '253', 'REFERENCIA COMPLEJA VÉASE ADEMÁS [FORMATO DE CLASIFICACIÓN]', 'REFERENCIA COMPLEJA VÉASE ADEMÁS [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '260', 'REFERENCIA COMPLEJA DE VÉASE--MATERIA', 'REFERENCIA COMPLEJA DE VÉASE--MATERIA', 1, 0, NULL),
		('', '336', 'TIPO DE CONTENIDO', 'TIPO DE CONTENIDO', 1, 0, NULL),
		('', '348', 'Formato de la música notada', 'Formato de la música notada', 1, 0, NULL),
		('', '353', 'REFERENCIA COMPLEJA DE VÉASE ADEMÁS [FORMATO DE CLASIFICACIÓN]', 'REFERENCIA COMPLEJA DE VÉASE ADEMÁS [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '360', 'REFERENCIA COMPLEJA DE VÉASE ADEMÁS-MATERIA', 'REFERENCIA COMPLEJA DE VÉASE ADEMÁS-MATERIA', 1, 0, NULL),
		('', '368', 'OTROS ATRIBUTOS DE PERSONA O ENTIDAD CORPORATIVA', 'OTROS ATRIBUTOS DE PERSONA O ENTIDAD CORPORATIVA', 1, 0, NULL),
		('', '370', 'LUGAR ASOCIADO', 'LUGAR ASOCIADO', 1, 0, NULL),
		('', '371', 'DIRECCIÓN', 'DIRECCIÓN', 1, 0, NULL),
		('', '372', 'CAMPO DE ACTIVIDAD', 'CAMPO DE ACTIVIDAD', 1, 0, NULL),
		('', '373', 'GRUPO ASOCIADO', 'GRUPO ASOCIADO', 1, 0, NULL),
		('', '374', 'OCUPACIÓN', 'OCUPACIÓN', 1, 0, NULL),
		('', '375', 'GÉNERO/SEXO', 'GÉNERO/SEXO', 1, 0, NULL),
		('', '376', 'INFORMACIÓN DE FAMILIA', 'INFORMACIÓN DE FAMILIA', 1, 0, NULL),
		('', '377', 'LENGUA/LENGUAJE ASOCIADO', 'LENGUA/LENGUAJE ASOCIADO', 1, 0, NULL),
		('', '378', 'FORMA COMPLETA/DESARROLLADA DEL NOMBRE', 'FORMA COMPLETA/DESARROLLADA DEL NOMBRE', 0, 0, NULL),
		('', '380', 'FORMA DE LA OBRA', 'FORMA DE LA OBRA', 1, 0, NULL),
		('', '381', 'OTRAS CARACTERÍSTICAS DISTINTIVAS DE OBRA O EXPRESIÓN', 'OTRAS CARACTERÍSTICAS DISTINTIVAS DE OBRA O EXPRESIÓN', 1, 0, NULL),
		('', '382', 'MEDIO DE INTERPRETACIÓN', 'MEDIO DE INTERPRETACIÓN', 1, 0, NULL),
		('', '383', 'DESIGNACIÓN NUMÉRICA DE OBRA MUSICAL', 'DESIGNACIÓN NUMÉRICA DE OBRA MUSICAL', 1, 0, NULL),
		('', '384', 'TONALIDAD/CLAVE', 'TONALIDAD/CLAVE', 0, 0, NULL),
		('', '385', 'CARACTERÍSTICAS DEL PÚBLICO', 'CARACTERÍSTICAS DEL PÚBLICO', 1, 0, NULL),
		('', '386', 'CARACTERÍSTICAS DEL CREADOR/COLABORADOR', 'CARACTERÍSTICAS DEL CREADOR/COLABORADOR', 1, 0, NULL),
		('', '388', 'PERIODO TEMPORAL DE CREACIÓN', 'PERIODO TEMPORAL DE CREACIÓN', 1, 0, NULL),
		('', '400', 'TRAZADO DE VÉASE--NOMBRE DE PERSONA', 'TRAZADO DE VÉASE--NOMBRE DE PERSONA', 1, 0, NULL),
		('', '410', 'TRAZADO DE VÉASE--NOMBRE DE ENTIDAD CORPORATIVA', 'TRAZADO DE VÉASE--NOMBRE DE ENTIDAD CORPORATIVA', 1, 0, NULL),
		('', '411', 'TRAZADO DE VÉASE--NOMBRE DE CONGRESO/REUNIÓN', 'TRAZADO DE VÉASE--NOMBRE DE CONGRESO/REUNIÓN', 1, 0, NULL),
		('', '430', 'TRAZADO DE VÉASE--TÍTULO UNIFORME', 'TRAZADO DE VÉASE--TÍTULO UNIFORME', 1, 0, NULL),
		('', '448', 'TRAZADO DE VÉASE--TÉRMINO CRONOLÓGICO', 'TRAZADO DE VÉASE--TÉRMINO CRONOLÓGICO', 1, 0, NULL),
		('', '450', 'TRAZADO DE VÉASE--TÉRMINO DE MATERIA', 'TRAZADO DE VÉASE--TÉRMINO DE MATERIA', 1, 0, NULL),
		('', '451', 'TRAZADO DE VÉASE--NOMBRE GEOGRÁFICO', 'TRAZADO DE VÉASE--NOMBRE GEOGRÁFICO', 1, 0, NULL),
		('', '453', 'NÚMERO DE TRAZADO INVÁLIDO [FORMATO DE CLASIFICACIÓN]', 'NÚMERO DE TRAZADO INVÁLIDO [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '455', 'TRAZADO DE VÉASE--TÉRMINO GÉNERO/FORMA', 'TRAZADO DE VÉASE--TÉRMINO GÉNERO/FORMA', 1, 0, NULL),
		('', '462', 'TRAZADO DE VÉASE-TÉRMINO DE MEDIO DE INTERPRETACIÓN', 'TRAZADO DE VÉASE-TÉRMINO DE MEDIO DE INTERPRETACIÓN', 1, 0, NULL),
		('', '480', 'TRAZADO DE VÉASE--SUBDIVISIÓN GENERAL', 'TRAZADO DE VÉASE--SUBDIVISIÓN GENERAL', 1, 0, NULL),
		('', '481', 'TRAZADO DE VÉASE--SUBDIVISIÓN GEOGRÁFICA', 'TRAZADO DE VÉASE--SUBDIVISIÓN GEOGRÁFICA', 1, 0, NULL),
		('', '482', 'TRAZADO DE VÉASE--SUBDIVISIÓN CRONOLÓGICA', 'TRAZADO DE VÉASE--SUBDIVISIÓN CRONOLÓGICA', 1, 0, NULL),
		('', '485', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN DE FORMA', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN DE FORMA', 1, 0, NULL),
		('', '500', 'TRAZADO DE VÉASE ADEMÁS--NOMBRE DE PERSONA', 'TRAZADO DE VÉASE ADEMÁS--NOMBRE DE PERSONA', 1, 0, NULL),
		('', '510', 'TRAZADO DE VÉASE ADEMÁS--NOMBRE DE ENTIDAD CORPORATIVA', 'TRAZADO DE VÉASE ADEMÁS--NOMBRE DE ENTIDAD CORPORATIVA', 1, 0, NULL),
		('', '511', 'TRAZADO DE VÉASE ADEMÁS--NOMBRE DE REUNIÓN/CONGRESO', 'TRAZADO DE VÉASE ADEMÁS--NOMBRE DE REUNIÓN/CONGRESO', 1, 0, NULL),
		('', '530', 'TRAZADO DE VÉASE ADEMÁS--TÍTULO UNIFORME', 'TRAZADO DE VÉASE ADEMÁS--TÍTULO UNIFORME', 1, 0, NULL),
		('', '548', 'TRAZADO DE VÉASE ADEMÁS--TÉRMINO CRONOLÓGICO', 'TRAZADO DE VÉASE ADEMÁS--TÉRMINO CRONOLÓGICO', 1, 0, NULL),
		('', '550', 'TRAZADO VÉASE ADEMÁS--TÉRMINO DE MATERIA', 'TRAZADO VÉASE ADEMÁS--TÉRMINO DE MATERIA', 1, 0, NULL),
		('', '551', 'TRAZADO DE VÉASE ADEMÁS--NOMBRE GEOGRÁFICO', 'TRAZADO DE VÉASE ADEMÁS--NOMBRE GEOGRÁFICO', 1, 0, NULL),
		('', '553', 'TRAZADO DE NÚMERO VÁLIDO [FORMATO DE CLASIFICACIÓN]', 'TRAZADO DE NÚMERO VÁLIDO [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '555', 'TRAZADO DE VÉASE ADEMÁS--TÉRMINO GÉNERO/FORMA', 'TRAZADO DE VÉASE ADEMÁS--TÉRMINO GÉNERO/FORMA', 1, 0, NULL),
		('', '562', 'TRAZADO DE VÉASE ADEMÁS-TÉRMINO DE MEDIO DE INTERPRETACIÓN', 'TRAZADO DE VÉASE ADEMÁS-TÉRMINO DE MEDIO DE INTERPRETACIÓN', 1, 0, NULL),
		('', '580', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN GENERAL', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN GENERAL', 1, 0, NULL),
		('', '581', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN GEOGRÁFICA', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN GEOGRÁFICA', 1, 0, NULL),
		('', '582', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN CRONOLÓGICA', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN CRONOLÓGICA', 1, 0, NULL),
		('', '585', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN DE FORMA', 'TRAZADO DE VÉASE ADEMÁS--SUBDIVISIÓN DE FORMA', 1, 0, NULL),
		('', '640', 'FECHAS DE PUBLICACIÓN DE SERIE Y/O DESIGNACIÓN SECUENCIAL', 'FECHAS DE PUBLICACIÓN DE SERIE Y/O DESIGNACIÓN SECUENCIAL', 1, 0, NULL),
		('', '641', 'PECULIARIDADES DE LA NUMERACIÓN EN SERIE', 'PECULIARIDADES DE LA NUMERACIÓN EN SERIE', 1, 0, NULL),
		('', '642', 'EJEMPLO DE NUMERACIÓN DE SERIE', 'EJEMPLO DE NUMERACIÓN DE SERIE', 1, 0, NULL),
		('', '643', 'LUGAR Y ENTIDAD EDITORA/EMISORA DE LA SERIE', 'LUGAR Y ENTIDAD EDITORA/EMISORA DE LA SERIE', 1, 0, NULL),
		('', '644', 'PRÁCTICA DE ANÁLISIS DE SERIE', 'PRÁCTICA DE ANÁLISIS DE SERIE', 1, 0, NULL),
		('', '645', 'PRÁCTICA EN EL TRAZADO DE SERIE', 'PRÁCTICA EN EL TRAZADO DE SERIE', 1, 0, NULL),
		('', '646', 'PRÁCTICA DE CLASIFICACIÓN DE LA SERIE', 'PRÁCTICA DE CLASIFICACIÓN DE LA SERIE', 1, 0, NULL),
		('', '663', 'REFERENCIA COMPLEJA DE VÉASE ADEMÁS--NOMBRE', 'REFERENCIA COMPLEJA DE VÉASE ADEMÁS--NOMBRE', 0, 0, NULL),
		('', '664', 'REFERENCIA COMPLEJA DE VÉASE--NOMBRE', 'REFERENCIA COMPLEJA DE VÉASE--NOMBRE', 0, 0, NULL),
		('', '665', 'REFERENCIA HISTÓRICA', 'REFERENCIA HISTÓRICA', 0, 0, NULL),
		('', '666', 'REFERENCIA EXPLICATIVA GENERAL--NOMBRE', 'REFERENCIA EXPLICATIVA GENERAL--NOMBRE', 0, 0, NULL),
		('', '667', 'NOTA GENERAL NO PÚBLICA', 'NOTA GENERAL NO PÚBLICA', 1, 0, NULL),
		('', '668', 'CARACTERES EN ALFABETO NO LATINO [OBSOLETO]', 'CARACTERES EN ALFABETO NO LATINO [OBSOLETO]', 1, 0, NULL),
		('', '670', 'FUENTE DE DATOS ENCONTRADOS', 'FUENTE DE DATOS ENCONTRADOS', 1, 0, NULL),
		('', '671', 'NOTA--OBRA CATALOGADA [OBSOLETO, SOLAMENTE CAN/MARC]', 'NOTA--OBRA CATALOGADA [OBSOLETO, SOLAMENTE CAN/MARC]', 1, 0, NULL),
		('', '672', 'TÍTULO RELACIONADO CON LA ENTIDAD', 'TÍTULO RELACIONADO CON LA ENTIDAD', 1, 0, NULL),
		('', '673', 'TÍTULO NO RELACIONADO CON LA ENTIDAD', 'TÍTULO NO RELACIONADO CON LA ENTIDAD', 1, 0, NULL),
		('', '675', 'FUENTE DE DATOS NO ENCONTRADOS', 'FUENTE DE DATOS NO ENCONTRADOS', 0, 0, NULL),
		('', '676', 'NOTA--REGLAS DE CATALOGACIÓN (NOMBRES/TÍTULOS) [OBSOLETO, SOLAMENTE CAN/MARC]', 'NOTA--REGLAS DE CATALOGACIÓN (NOMBRES/TÍTULOS) [OBSOLETO, SOLAMENTE CAN/MARC]', 0, 0, NULL),
		('', '678', 'DATOS BIOGRÁFICOS O HISTÓRICOS', 'DATOS BIOGRÁFICOS O HISTÓRICOS', 1, 0, NULL),
		('', '680', 'NOTA GENERAL PÚBLICA', 'NOTA GENERAL PÚBLICA', 1, 0, NULL),
		('', '681', 'NOTA DE EJEMPLO DE TRAZADO DE MATERIA', 'NOTA DE EJEMPLO DE TRAZADO DE MATERIA', 1, 0, NULL),
		('', '682', 'INFORMACIÓN DE ENCABEZAMIENTO ELIMINADO', 'INFORMACIÓN DE ENCABEZAMIENTO ELIMINADO', 0, 0, NULL),
		('', '683', 'NOTA DE HISTORIA DE LA APLICACIÓN', 'NOTA DE HISTORIA DE LA APLICACIÓN', 1, 0, NULL),
		('', '684', 'NOTA DE INSTRUCCIÓN AUXILIAR [FORMATO DE CLASIFICACIÓN]', 'NOTA DE INSTRUCCIÓN AUXILIAR [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '685', 'NOTA--FUENTE DE LOS DATOS ENCONTRADOS (MATERIA) [OBSOLETO, SOLAMENTE CAN/MARC]', 'NOTA--FUENTE DE LOS DATOS ENCONTRADOS (MATERIA) [OBSOLETO, SOLAMENTE CAN/MARC]', 1, 0, NULL),
		('', '686', 'NOTA--FUENTE DE DATOS NO ENCONTRADOS (MATERIA) [OBSOLETO, SOLAMENTE CAN/MARC]', 'NOTA--FUENTE DE DATOS NO ENCONTRADOS (MATERIA) [OBSOLETO, SOLAMENTE CAN/MARC]', 1, 0, NULL),
		('', '687', 'NOTA--USO (MATERIA) [OBSOLETO, SOLAMENTE CAN/MARC]', 'NOTA--USO (MATERIA) [OBSOLETO, SOLAMENTE CAN/MARC]', 1, 0, NULL),
		('', '688', 'NOTA DE HISTORIA DE LA APLICACIÓN', 'NOTA DE HISTORIA DE LA APLICACIÓN', 1, 0, NULL),
		('', '700', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--NOMBRE DE PERSONA', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--NOMBRE DE PERSONA', 1, 0, NULL),
		('', '710', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--NOMBRE DE ENTIDAD CORPORATIVA', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--NOMBRE DE ENTIDAD CORPORATIVA', 1, 0, NULL),
		('', '711', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--NOMBRE DE REUNIÓN/CONGRESO', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--NOMBRE DE REUNIÓN/CONGRESO', 1, 0, NULL),
		('', '730', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--TÍTULO UNIFORME', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--TÍTULO UNIFORME', 1, 0, NULL),
		('', '748', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--TÉRMINO CRONOLÓGICO', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--TÉRMINO CRONOLÓGICO', 1, 0, NULL),
		('', '750', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--TÉRMINO DE MATERIA', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--TÉRMINO DE MATERIA', 1, 0, NULL),
		('', '751', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--NOMBRE GEOGRÁFICO', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO--NOMBRE GEOGRÁFICO', 1, 0, NULL),
		('', '753', 'TÉRMINO DE ÍNDICE--NO CONTROLADO [FORMATO DE CLASIFICACIÓN]', 'TÉRMINO DE ÍNDICE--NO CONTROLADO [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '754', 'TÉRMINO DEL ÍNDICE--TÉRMINOS DE MATERIA POR FACETAS [FORMATO DE CLASIFICACIÓN]', 'TÉRMINO DEL ÍNDICE--TÉRMINOS DE MATERIA POR FACETAS [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '755', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO-–TÉRMINO DE GÉNERO/FORMA', 'ENTRADA DE ENLACE DE ENCABEZAMIENTO ESTABLECIDO-–TÉRMINO DE GÉNERO/FORMA', 1, 0, NULL),
		('', '761', 'INSTRUCCIONES DE ADHIERA O DIVIDA COMO [FORMATO DE CLASIFICACIÓN]', 'INSTRUCCIONES DE ADHIERA O DIVIDA COMO [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '762', 'ENCABEZAMIENTO ESTABLECIDO ENTRADA DE ENLACE-TÉRMINO DE MEDIO DE INTERPRETACIÓN', 'ENCABEZAMIENTO ESTABLECIDO ENTRADA DE ENLACE-TÉRMINO DE MEDIO DE INTERPRETACIÓN', 1, 0, NULL),
		('', '763', 'SUBARREGLO INTERNO O ENTRADA DE TABLA ADHERIDA [FORMATO DE CLASIFICACIÓN]', 'SUBARREGLO INTERNO O ENTRADA DE TABLA ADHERIDA [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '764', 'IDENTIFICACIÓN DE REGLA [FORMATO DE CLASIFICACIÓN]', 'IDENTIFICACIÓN DE REGLA [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '765', 'COMPONENTES DE NÚMERO SINTETIZADO [FORMATO DE CLASIFICACIÓN]', 'COMPONENTES DE NÚMERO SINTETIZADO [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '766', 'INFORMACIÓN DE TABLA SECUNDARIA [FORMATO DE CLASIFICACIÓN]', 'INFORMACIÓN DE TABLA SECUNDARIA [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '768', 'CITACIÓN E INSTRUCCIONES EN ORDEN DE PREFERENCIA [FORMATO DE CLASIFICACIÓN]', 'CITACIÓN E INSTRUCCIONES EN ORDEN DE PREFERENCIA [FORMATO DE CLASIFICACIÓN]', 1, 0, NULL),
		('', '780', 'ENTRADA DE ENLACE DE SUBDIVISIÓN--SUBDIVISIÓN GENERAL', 'ENTRADA DE ENLACE DE SUBDIVISIÓN--SUBDIVISIÓN GENERAL', 1, 0, NULL),
		('', '781', 'ENTRADA DE ENLACE DE SUBDIVISIÓN--SUBDIVISIÓN GEOGRÁFICA', 'ENTRADA DE ENLACE DE SUBDIVISIÓN--SUBDIVISIÓN GEOGRÁFICA', 1, 0, NULL),
		('', '782', 'ENTRADA DE ENLACE DE SUBDIVISIÓN--SUBDIVISIÓN CRONOLÓGICA', 'ENTRADA DE ENLACE DE SUBDIVISIÓN--SUBDIVISIÓN CRONOLÓGICA', 1, 0, NULL),
		('', '785', 'ENTRADA DE ENLACE DE SUBDIVISIÓN--SUBDIVISIÓN DE FORMA', 'ENTRADA DE ENLACE DE SUBDIVISIÓN--SUBDIVISIÓN DE FORMA', 1, 0, NULL),
		('', '788', 'DATOS DE ENTRADA DE ENLACE COMPLEJO', 'DATOS DE ENTRADA DE ENLACE COMPLEJO', 0, 0, NULL),
		('', '856', 'LOCALIZACIÓN Y ACCESO ELECTRÓNICOS', 'LOCALIZACIÓN Y ACCESO ELECTRÓNICOS', 1, 0, NULL),
		('', '880', 'REPRESENTACIÓN GRÁFICA ALTERNATIVA', 'REPRESENTACIÓN GRÁFICA ALTERNATIVA', 1, 0, NULL),
		('', '883', 'PROCEDENCIA DE LOS METADATOS GENERADOS POR ORDENADOR', 'PROCEDENCIA DE LOS METADATOS GENERADOS POR ORDENADOR', 1, 0, NULL),
		('', '884', 'Información sobre la conversión de la descripción', 'Información sobre la conversión de la descripción', 1, 0, NULL),
		('', '942', 'USO INTERNO DE KOHA', 'USO INTERNO DE KOHA', 0, 1, NULL);



INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`) VALUES
		('', '000', '@', 'campo de control de longitud fija', 'campo de control de longitud fija', 0, 1, 0, NULL, 'marc21_leader_authorities.pl', NULL, 0, 0, 0, '', ''),
		('', '001', '@', 'campo de control', 'campo de control', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, 'auth_header.authid', ''),
		('', '003', '@', 'campo de control', 'campo de control', 0, 1, 0, NULL, 'marc21_orgcode.pl', NULL, 0, 0, 0, '', ''),
		('', '005', '@', 'campo de control', 'campo de control', 0, 1, 0, NULL, 'marc21_field_005.pl', NULL, 0, 0, 0, '', ''),
		('', '008', '@', 'campo de control de longitud fija', 'campo de control de longitud fija', 0, 1, 0, NULL, 'marc21_field_008_authorities.pl', NULL, 0, 0, 0, '', ''),
		('', '010', 'a', 'Número de control de LC', 'Número de control de LC', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '010', 'z', 'Número de control de LC cancelado o no válido', 'Número de control de LC cancelado o no válido', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '010', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '014', 'a', 'Número de control del registro bibliográfico relacionado', 'Número de control del registro bibliográfico relacionado', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '014', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '014', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '016', 'a', 'Número de control del registro', 'Número de control del registro', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '016', 'z', 'Número de control cancelado o inválido', 'Número de control cancelado o inválido', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '016', '2', 'Fuente', 'Fuente', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '016', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '020', 'a', 'Número Internacional Estándar del Libro', 'Número Internacional Estándar del Libro', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '020', 'c', 'Condiciones de disponibilidad', 'Condiciones de disponibilidad', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '020', 'q', 'Información calificativa', 'Información calificativa', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '020', 'z', 'ISBN cancelado o inválido', 'ISBN cancelado o inválido', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '020', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '020', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '022', 'a', 'Número Internacional Normalizado para Publicaciones Seriadas', 'Número Internacional Normalizado para Publicaciones Seriadas', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '022', 'l', 'ISSN-L', 'ISSN-L', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '022', 'm', 'ISSN-L Cancelado', 'ISSN-L Cancelado', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '022', 'y', 'ISSN Incorrecto', 'ISSN Incorrecto', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '022', 'z', 'ISSN Cancelado', 'ISSN Cancelado', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '022', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '022', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '024', 'a', 'Número estándar o código', 'Número estándar o código', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '024', 'c', 'Condiciones de disponibilidad', 'Condiciones de disponibilidad', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '024', 'd', 'Códigos adicionales siguiendo el número estándar o código', 'Códigos adicionales siguiendo el número estándar o código', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '024', 'q', 'Información calificativa', 'Información calificativa', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '024', 'z', 'Número estándar o código cancelado o inválido', 'Número estándar o código cancelado o inválido', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '024', '2', 'Fuente del número o código', 'Fuente del número o código', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '024', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '024', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'a', 'Número de obra', 'Número de obra', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'b', 'Número del movimiento', 'Número del movimiento', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'c', 'Número del pasaje', 'Número del pasaje', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'd', 'Título o cabecera', 'Título o cabecera', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'e', 'Personaje/Rol', 'Personaje/Rol', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'g', 'Clave musical', 'Clave musical', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'm', 'Voz/instrumento', 'Voz/instrumento', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'n', 'Armadura de clave', 'Armadura de clave', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'o', 'Signatura de compás/Marca de tiempo', 'Signatura de compás/Marca de tiempo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'p', 'Notación musical', 'Notación musical', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'q', 'Nota general', 'Nota general', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'r', 'Tonalidad o modo', 'Tonalidad o modo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 's', 'Nota de validez codificada', 'Nota de validez codificada', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 't', 'Texto del íncipit', 'Texto del íncipit', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'y', 'Texto de enlace', 'Texto de enlace', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', 'z', 'Nota pública', 'Nota pública', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', '2', 'Código de sistema', 'Código de sistema', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '031', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'd', 'Coordenadas - longitud más occidental', 'Coordenadas - longitud más occidental', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'e', 'Coordenadas - longitud más oriental', 'Coordenadas - longitud más oriental', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'f', 'Coordenadas - latitud más septentrional', 'Coordenadas - latitud más septentrional', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'g', 'Coordenadas - latitud más meridional', 'Coordenadas - latitud más meridional', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'j', 'Declinación-límite septentrional', 'Declinación-límite septentrional', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'k', 'Declinación-límite meridional', 'Declinación-límite meridional', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'm', 'Ascensión recta-límite oriental', 'Ascensión recta-límite oriental', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'n', 'Ascensión recta-límite occidental', 'Ascensión recta-límite occidental', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'p', 'Equinoccio', 'Equinoccio', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'r', 'Distancia desde la tierra', 'Distancia desde la tierra', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 's', 'Latitud del anillo-G', 'Latitud del anillo-G', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 't', 'Longitud del anillo-G', 'Longitud del anillo-G', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'x', 'Fecha de inicio', 'Fecha de inicio', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'y', 'Fecha de finalización', 'Fecha de finalización', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', 'z', 'Nombre del cuerpo extraterrestre', 'Nombre del cuerpo extraterrestre', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', '2', 'Fuente', 'Fuente', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', '3', 'Especificación de materiales', 'Especificación de materiales', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '034', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '035', 'a', 'Número de control de sistema', 'Número de control de sistema', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '035', 'z', 'Número de control cancelado/no válido', 'Número de control cancelado/no válido', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '035', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '035', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '040', 'a', 'Centro catalogador/agencia de origen', 'Centro catalogador/agencia de origen', 0, 1, 0, NULL, 'marc21_orgcode.pl', NULL, 0, 0, 0, '', ''),
		('', '040', 'b', 'Lengua de catalogación', 'Lengua de catalogación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '040', 'c', 'Centro/agencia transcriptor', 'Centro/agencia transcriptor', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '040', 'd', 'Centro/agencia modificador', 'Centro/agencia modificador', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '040', 'e', 'Normas de descripción', 'Normas de descripción', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '040', 'f', 'Convención/Normas de encabezamiento de materia/tesauro', 'Convención/Normas de encabezamiento de materia/tesauro', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '040', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '040', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '042', 'a', 'Código de autenticación', 'Código de autenticación', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '043', 'a', 'Código de área geográfica', 'Código de área geográfica', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '043', 'b', 'Código local GAC', 'Código local GAC', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '043', 'c', 'Código ISO', 'Código ISO', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '043', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '043', '2', 'Fuente del código local', 'Fuente del código local', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '043', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '043', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '045', 'a', 'Código de periodo de tiempo', 'Código de periodo de tiempo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '045', 'b', 'Periodo de tiempo normalizado, posterior a 9999 a.C.', 'Periodo de tiempo normalizado, posterior a 9999 a.C.', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '045', 'c', 'Periodo de tiempo normalizado, anterior a 9999 a.C.', 'Periodo de tiempo normalizado, anterior a 9999 a.C.', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '045', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '045', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'f', 'Fecha de nacimiento', 'Fecha de nacimiento', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'g', 'Fecha de la muerte', 'Fecha de la muerte', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'k', 'Fecha única o de inicio de la creación', 'Fecha única o de inicio de la creación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'l', 'Fecha de finalización de la creación', 'Fecha de finalización de la creación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'o', 'Fecha única o fecha inicial para contenidos agregados', 'Fecha única o fecha inicial para contenidos agregados', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'p', 'Fecha final para contenidos agregados', 'Fecha final para contenidos agregados', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'q', 'Fecha de constitución ', 'Fecha de constitución ', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'r', 'Fecha de finalización', 'Fecha de finalización', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 's', 'Período de inicio', 'Período de inicio', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 't', 'Fin de período', 'Fin de período', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', '2', 'Fuente del esquema de fecha', 'Fuente del esquema de fecha', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '046', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '050', 'a', 'Número de clasificación', 'Número de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '050', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '050', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '050', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '050', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '050', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '052', 'a', 'Código de clasificación de área geográfica', 'Código de clasificación de área geográfica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '052', 'b', 'Código de clasificación de subárea geográfica', 'Código de clasificación de subárea geográfica', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '052', 'd', 'Nombre de la población', 'Nombre de la población', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '052', '2', 'Fuente del código', 'Fuente del código', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '052', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '052', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '053', 'a', 'Número de clasificación–único número o número inicial del rango', 'Número de clasificación–único número o número inicial del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '053', 'b', 'Número de clasificación–último número del rango', 'Número de clasificación–último número del rango', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '053', 'c', 'Término explicativo', 'Término explicativo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '053', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '053', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '053', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '055', 'a', 'Número de clasificación', 'Número de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '055', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '055', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '055', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '055', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '055', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '058', 'a', 'Numero de clasificación LC--Único número o número inicial de un rango', 'Numero de clasificación LC--Único número o número inicial de un rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '058', 'b', 'Número de clasificación LC--Numero de finalización de un rango', 'Número de clasificación LC--Numero de finalización de un rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '058', 'c', 'Término explicativo', 'Término explicativo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '058', '5', 'Biblioteca a la cual aplica el número de clasificación', 'Biblioteca a la cual aplica el número de clasificación', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '058', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '060', 'a', 'Número de clasificación', 'Número de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '060', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '060', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '060', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '060', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '060', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '063', 'a', 'Número de clasificación NLM--Único número o número inicial de un rango', 'Número de clasificación NLM--Único número o número inicial de un rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '063', 'b', 'Número de clasificación NLM--Número de finalización de un rango', 'Número de clasificación NLM--Número de finalización de un rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '063', 'c', 'Término explicativo', 'Término explicativo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '065', 'a', 'Número de clasificación–único número o número inicial del rango', 'Número de clasificación–único número o número inicial del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '065', 'b', 'Número de clasificación–último número del rango', 'Número de clasificación–último número del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '065', 'c', 'Término explicativo', 'Término explicativo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '065', '2', 'Fuente del número', 'Fuente del número', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '065', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '065', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '065', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '066', 'a', 'Juego/conjunto de caracteres básicos G0', 'Juego/conjunto de caracteres básicos G0', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '066', 'b', 'Juego/conjunto de caracteres básico G1', 'Juego/conjunto de caracteres básico G1', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '066', 'c', 'Juego/conjunto de caracteres alternativo G0 o G1', 'Juego/conjunto de caracteres alternativo G0 o G1', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '068', 'a', 'Número de clasificación NLM--Único número o número inicial de un rango', 'Número de clasificación NLM--Único número o número inicial de un rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '068', 'b', 'Número de clasificación NLM--Número de finalización de un rango', 'Número de clasificación NLM--Número de finalización de un rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '068', 'c', 'Término explicativo', 'Término explicativo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '068', '5', 'Biblioteca a la cual aplica el número de clasificación', 'Biblioteca a la cual aplica el número de clasificación', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '070', 'a', 'Número de clasificación', 'Número de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '070', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '070', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '070', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '070', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '072', 'a', 'Código de categoría de materia', 'Código de categoría de materia', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '072', 'x', 'Subdivisión del código de categoría de materia', 'Subdivisión del código de categoría de materia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '072', '2', 'Fuente del código', 'Fuente del código', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '072', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '072', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '073', 'a', 'Uso de subdivisión', 'Uso de subdivisión', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '073', 'z', 'Fuente del código', 'Fuente del código', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '073', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '073', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '080', 'a', 'Número de la Clasificación Decimal Universal', 'Número de la Clasificación Decimal Universal', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '080', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '080', 'x', 'Subdivisión auxiliar común', 'Subdivisión auxiliar común', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '080', '2', 'Identificador de la edición', 'Identificador de la edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '080', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '080', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '083', 'y', 'Número secuencial de tabla para subordenación interna o tabla añadida', 'Número secuencial de tabla para subordenación interna o tabla añadida', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '082', 'a', 'Número de clasificación', 'Número de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '082', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '082', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '082', '2', 'Número de edición', 'Número de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '082', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '082', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '082', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '083', 'a', 'Número de clasificación–único número o número inicial del rango', 'Número de clasificación–único número o número inicial del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '083', 'b', 'Número de clasificación–último número del rango', 'Número de clasificación–último número del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '083', 'c', 'Término explicativo', 'Término explicativo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '083', 'z', 'Identificación de tabla-número de tabla', 'Identificación de tabla-número de tabla', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '083', '2', 'Número de edición', 'Número de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '083', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '083', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '083', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '084', 'a', 'Código de esquema de clasificación', 'Código de esquema de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '084', 'b', 'Título de edición', 'Título de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '084', 'c', 'Identificador de la edición', 'Identificador de la edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '084', 'd', 'Identificador de fuente de edición', 'Identificador de fuente de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '084', 'e', 'Código del idioma', 'Código del idioma', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '084', 'f', 'Autorización', 'Autorización', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '084', 'n', 'Variaciones', 'Variaciones', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '084', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '084', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '086', 'a', 'Número de clasificación', 'Número de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '086', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '086', 'z', 'Signatura topográfica cancelada/no válida', 'Signatura topográfica cancelada/no válida', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '086', '2', 'Fuente del número', 'Fuente del número', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '086', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '086', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '086', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '087', 'a', 'Elemento número de clasificación-número individual o inicio de un rango', 'Elemento número de clasificación-número individual o inicio de un rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '087', 'b', 'Elemento número de clasificación-Último número del rango', 'Elemento número de clasificación-Último número del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '087', 'c', 'Información explicativa', 'Información explicativa', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '087', '2', 'Fuente del número', 'Fuente del número', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '087', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '087', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '088', 'a', 'Número de estantería del documento (CODOC)', 'Número de estantería del documento (CODOC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'a', 'Signatura topográfica ; Número de clasificación (OCLC) (R) ; Número de clasificación, CALL (RLIN) (NR)', 'Signatura topográfica ; Número de clasificación (OCLC) (R) ; Número de clasificación, CALL (RLIN) (NR)', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'b', 'Número de ítem ; Número cutter local (OCLC) ; Número de libro/Signatura topográfica íntegra, CALL (RLIN)', 'Número de ítem ; Número cutter local (OCLC) ; Número de libro/Signatura topográfica íntegra, CALL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'e', 'Característica del encabezamiento (OCLC)', 'Característica del encabezamiento (OCLC)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'f', 'Sufijo de archivo (OCLC) ; Nota a pie de página, FNT (RLIN)', 'Sufijo de archivo (OCLC) ; Nota a pie de página, FNT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'h', 'Notas adicionales locales, ANT (RLIN)', 'Notas adicionales locales, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'i', 'Instrucción de transacción de salida, INS (RLIN)', 'Instrucción de transacción de salida, INS (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'l', 'Mención de ficha de control extra, EXT (RLIN)', 'Mención de ficha de control extra, EXT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'n', 'Notas locales adicionales, ANT (RLIN)', 'Notas locales adicionales, ANT (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'p', 'Código pathfinder, PTH (RLIN)', 'Código pathfinder, PTH (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 't', 'Campo de supresión, FSP (RLIN)', 'Campo de supresión, FSP (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'v', 'Volúmenes, VOL (RLIN)', 'Volúmenes, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'y', 'Fecha, VOL (RLIN)', 'Fecha, VOL (RLIN)', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', 'z', 'Signatura topográfica cancelada/no válida', 'Signatura topográfica cancelada/no válida', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', '2', 'Fuente del número', 'Fuente del número', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '090', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '091', 'a', 'Elemento número de clasificación--único número o número inicial del rango', 'Elemento número de clasificación--único número o número inicial del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '091', 'b', 'Elemento número de clasificación-último número del rango', 'Elemento número de clasificación-último número del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '091', 'c', 'Término explicativo', 'Término explicativo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '091', 'z', 'Identificación de tabla-número de tabla', 'Identificación de tabla-número de tabla', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '091', '2', 'Número de edición', 'Número de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '091', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '091', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '091', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '092', 'a', 'Número de clasificación', 'Número de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '092', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '092', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '092', 'e', 'Característica del encabezamiento', 'Característica del encabezamiento', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '092', 'f', 'Sufijo de archivo', 'Sufijo de archivo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '092', '2', 'Número de edición', 'Número de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '092', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '092', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '092', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '093', 'a', 'Elemento número de clasificación--único número o número inicial del rango', 'Elemento número de clasificación--único número o número inicial del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '093', 'b', 'Elemento número de clasificación-último número del rango', 'Elemento número de clasificación-último número del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '093', 'c', 'Término explicativo', 'Término explicativo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '093', 'z', 'Identificación de tabla-número de tabla', 'Identificación de tabla-número de tabla', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '093', '2', 'Número de edición', 'Número de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '093', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '093', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '093', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '096', 'a', 'Número de clasificación', 'Número de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '096', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '096', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '096', 'e', 'Característica del encabezamiento', 'Característica del encabezamiento', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '096', 'f', 'Sufijo de archivo', 'Sufijo de archivo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '096', '2', 'Número de edición', 'Número de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '096', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '096', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '096', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '097', 'a', 'Elemento número de clasificación--único número o número inicial del rango', 'Elemento número de clasificación--único número o número inicial del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '097', 'b', 'Elemento número de clasificación-último número del rango', 'Elemento número de clasificación-último número del rango', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '097', 'c', 'Término explicativo', 'Término explicativo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '097', 'z', 'Identificación de tabla-número de tabla', 'Identificación de tabla-número de tabla', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '097', '2', 'Número de edición', 'Número de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '097', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '097', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '097', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '098', 'a', 'Signatura topográfica basada en otros esquemas de clasificación', 'Signatura topográfica basada en otros esquemas de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '098', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '098', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '098', 'e', 'Característica del encabezamiento', 'Característica del encabezamiento', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '098', 'f', 'Sufijo de archivo', 'Sufijo de archivo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '098', '2', 'Número de edición', 'Número de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '098', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '098', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '098', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '099', 'a', 'Número de clasificación', 'Número de clasificación', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '099', 'b', 'Número de documento/Ítem', 'Número de documento/Ítem', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '099', 'd', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 'Volúmenes/fechas a la cual la signatura topográfica aplica', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '099', 'e', 'Característica del encabezamiento', 'Característica del encabezamiento', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '099', 'f', 'Sufijo de archivo', 'Sufijo de archivo', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '099', '2', 'Número de edición', 'Número de edición', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '099', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '099', '6', 'Enlace', 'Enlace', 0, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '099', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 0, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'a', 'Nombre de persona', 'Nombre de persona', 0, 0, 1, NULL, NULL, '''100b'',''100c'',''100q'',''100d'',''100t'',''100o'',''100m'',''100r'',''100s'',''100k'',''100n'',''100p'',''100g'',''100l'',''100f'',''100h'',''100x'',''100z'',''100y'',''100v''', 0, 0, 0, '', ''),
		('', '100', 'b', 'Numeración', 'Numeración', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'c', 'Títulos y otros términos asociados al nombre', 'Títulos y otros términos asociados al nombre', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'd', 'Fechas asociadas al nombre', 'Fechas asociadas al nombre', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'e', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'h', 'Medio', 'Medio', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'j', 'Calificador de atribución', 'Calificador de atribución', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'n', 'Número de parte o sección de la obra', 'Número de parte o sección de la obra', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'q', 'Forma completa/desarrollada del nombre', 'Forma completa/desarrollada del nombre', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'r', 'Clave para música', 'Clave para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 's', 'Versión', 'Versión', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 't', 'Título de la obra', 'Título de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '100', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'a', 'Nombre de entidad corporativa o nombre de jurisdicción como elemento de entrada', 'Nombre de entidad corporativa o nombre de jurisdicción como elemento de entrada', 0, 0, 1, NULL, NULL, '''110b'',''110c'',''110d'',''110t'',''110o'',''110m'',''110r'',''110s'',''110k'',''110n'',''110p'',''110g'',''110l'',''110f'',''110h'',''110x'',''110z'',''110y'',''110v''', 0, 0, 0, '', ''),
		('', '110', 'b', 'Unidad subordinada', 'Unidad subordinada', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'c', 'Sede del congreso/Lugar de la reunión', 'Sede del congreso/Lugar de la reunión', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'd', 'Fecha del congreso/reunión o de la firma de un tratado', 'Fecha del congreso/reunión o de la firma de un tratado', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'e', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'h', 'Medio', 'Medio', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'n', 'Número del congreso/reunión o número de parte o sección', 'Número del congreso/reunión o número de parte o sección', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'r', 'Clave para música', 'Clave para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 's', 'Versión', 'Versión', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 't', 'Título de la obra', 'Título de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '110', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'a', 'Nombre de congreso/reunión o jurisdicción como elemento de entrada', 'Nombre de congreso/reunión o jurisdicción como elemento de entrada', 0, 0, 1, NULL, NULL, '''111e'',''111c'',''111d'',''111t'',''111s'',''111k'',''111n'',''111p'',''111g'',''111l'',''111f'',''111h'',''111x'',''111z'',''111y'',''111v''', 0, 0, 0, '', ''),
		('', '111', 'b', 'Número [OBSOLETO]', 'Número [OBSOLETO]', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'c', 'Sede del congreso/Lugar de la reunión', 'Sede del congreso/Lugar de la reunión', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'd', 'Fecha del congreso/reunión', 'Fecha del congreso/reunión', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'e', 'Unidad subordinada', 'Unidad subordinada', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'h', 'Medio', 'Medio', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'j', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'n', 'Número del congreso/reunión o número de parte o sección', 'Número del congreso/reunión o número de parte o sección', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'q', 'Nombre de congreso/reunión que sigue a un nombre de jurisdicción como elemento de entrada', 'Nombre de congreso/reunión que sigue a un nombre de jurisdicción como elemento de entrada', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 's', 'Versión', 'Versión', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 't', 'Título de la obra', 'Título de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '111', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'a', 'Título uniforme', 'Título uniforme', 0, 0, 1, NULL, NULL, '''130o'',''130m'',''130r'',''130s'',''130d'',''130k'',''130n'',''130p'',''130g'',''130l'',''130f'',''130h'',''130t'',''130x'',''130z'',''130y'',''130v''', 0, 0, 0, '', ''),
		('', '130', 'd', 'Fecha de la firma de un tratado', 'Fecha de la firma de un tratado', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'h', 'Medio', 'Medio', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'n', 'Número de parte o sección de la obra', 'Número de parte o sección de la obra', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'r', 'Clave para música', 'Clave para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 's', 'Versión', 'Versión', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 't', 'Título de la obra', 'Título de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '130', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'a', 'Título uniforme', 'Título uniforme', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'd', 'Fecha de tratado', 'Fecha de tratado', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'g', 'Información miscelánea', 'Información miscelánea', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'h', 'Designación general del material', 'Designación general del material', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'l', 'Lenguaje/Lengua', 'Lenguaje/Lengua', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'n', 'Número de parte o sección/publicación seriada, temática, o número de opus', 'Número de parte o sección/publicación seriada, temática, o número de opus', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'o', 'Arreglo o arr. para música', 'Arreglo o arr. para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'p', 'Parte o sección', 'Parte o sección', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'r', 'Clave para música', 'Clave para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'x', 'Subdivisión general de materia', 'Subdivisión general de materia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'y', 'Subdivisión de materia para período', 'Subdivisión de materia para período', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '140', 'z', 'Subdivisión de materia de lugar', 'Subdivisión de materia de lugar', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'a', 'Título colectivo', 'Título colectivo', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'd', 'Fecha de tratado', 'Fecha de tratado', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'g', 'Información miscelánea', 'Información miscelánea', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'h', 'Designación general del material', 'Designación general del material', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'l', 'Lenguaje/Lengua', 'Lenguaje/Lengua', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'n', 'Número de parte o sección/publicación seriada, temática, o número de opus', 'Número de parte o sección/publicación seriada, temática, o número de opus', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'o', 'Arreglo o arr. para música', 'Arreglo o arr. para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'p', 'Parte o sección', 'Parte o sección', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 'r', 'Clave para música', 'Clave para música', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '143', 's', 'Versión', 'Versión', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '148', 'a', 'Término cronológico', 'Término cronológico', 0, 0, 1, NULL, NULL, '''148y'',''148x'',''148z'',''148v''', 0, 0, 0, '', ''),
		('', '148', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '148', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '148', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '148', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '148', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '148', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '150', 'a', 'Término de materia o nombre geográfico como elemento de entrada', 'Término de materia o nombre geográfico como elemento de entrada', 0, 0, 1, NULL, NULL, '''150x'',''150z'',''150y'',''150v''', 0, 0, 0, '', ''),
		('', '150', 'b', 'Término de materia que sigue a un nombre geográfico como elemento de entrada', 'Término de materia que sigue a un nombre geográfico como elemento de entrada', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '150', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '150', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '150', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '150', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '150', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '150', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '150', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '151', 'a', 'Nombre geográfico', 'Nombre geográfico', 0, 0, 1, NULL, NULL, '''151z'',''151x'',''151y'',''151v''', 0, 0, 0, '', ''),
		('', '151', 'b', 'Nombre que sigue a un elemento de entrada {OBSOLETO]', 'Nombre que sigue a un elemento de entrada {OBSOLETO]', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '151', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '151', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '151', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '151', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '151', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '151', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '151', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '153', 'a', 'Número de clasificación--Único número o número inicial del rango', 'Número de clasificación--Único número o número inicial del rango', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '153', 'c', 'Número de clasificación--Último número del rango', 'Número de clasificación--Último número del rango', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '153', 'h', 'Jerarquía de epígrafe', 'Jerarquía de epígrafe', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '153', 'j', 'Epígrafe', 'Epígrafe', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '153', 'k', 'Número sumario rango de jerarquía de epígrafe', 'Número sumario rango de jerarquía de epígrafe', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '153', 'z', 'Identificador de tabla', 'Identificador de tabla', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '153', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '153', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '154', 'a', 'Término explicativo general de índice', 'Término explicativo general de índice', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '154', 'b', 'Término explicativo general de índice--Nivel subsiguiente', 'Término explicativo general de índice--Nivel subsiguiente', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '154', 'f', 'Identificación del esquema', 'Identificación del esquema', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '154', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '154', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '155', 'a', 'Término de género/forma', 'Término de género/forma', 0, 0, 1, NULL, NULL, '''155v'',''155x'',''155z'',''155y''', 0, 0, 0, '', ''),
		('', '155', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '155', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '155', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '155', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '155', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '155', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '162', 'a', 'Término de medio de interpretación', 'Término de medio de interpretación', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '162', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '162', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '180', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '180', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '180', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '180', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '180', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '180', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '181', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '181', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '181', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '181', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '181', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '181', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '182', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '182', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '182', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '182', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '182', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '182', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '185', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '185', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '185', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '185', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '185', '6', 'Enlace', 'Enlace', 0, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '185', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 1, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '253', 'a', 'Número de clasificación de la referencia--único número o número inicial del rango', 'Número de clasificación de la referencia--único número o número inicial del rango', 1, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '253', 'c', 'Número de clasificación de la referencia--Último número del rango', 'Número de clasificación de la referencia--Último número del rango', 1, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '253', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '253', 'y', 'Tabla de identificación--Esquema [OBSOLETO]', 'Tabla de identificación--Esquema [OBSOLETO]', 0, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '253', 'z', 'Identificador de tabla', 'Identificador de tabla', 1, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '253', '6', 'Enlace', 'Enlace', 0, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '253', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '260', 'a', 'Encabezamiento referido a', 'Encabezamiento referido a', 1, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '260', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '260', '0', 'Número de control de registro de autoridad', 'Número de control de registro de autoridad', 1, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '260', '6', 'Enlace', 'Enlace', 0, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '260', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 2, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '336', 'a', 'Término de tipo de contenido', 'Término de tipo de contenido', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '336', 'b', 'Código de tipo de contenido', 'Código de tipo de contenido', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '336', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '336', '2', 'Fuente', 'Fuente', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '336', '3', 'Especificación de materiales', 'Especificación de materiales', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '336', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '336', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '348', 'a', 'Término del formato de la música notada', 'Término del formato de la música notada', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '348', 'b', 'Código del formato de la música notada', 'Código del formato de la música notada', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '348', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '348', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '348', '3', 'Especificación de materiales', 'Especificación de materiales', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '348', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '348', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '353', 'a', 'Número de clasificación de la referencia--único número o número inicial del rango', 'Número de clasificación de la referencia--único número o número inicial del rango', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '353', 'c', 'Número de clasificación de la referencia--Último número del rango', 'Número de clasificación de la referencia--Último número del rango', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '353', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '353', 'y', 'Tabla de identificación--Esquema [OBSOLETO]', 'Tabla de identificación--Esquema [OBSOLETO]', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '353', 'z', 'Identificador de tabla', 'Identificador de tabla', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '353', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '353', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '360', 'a', 'Encabezamiento referido a', 'Encabezamiento referido a', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '360', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '360', '0', 'Número de control de registro de autoridad', 'Número de control de registro de autoridad', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '360', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '360', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', 'a', 'Tipo de entidad corporativa', 'Tipo de entidad corporativa', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', 'b', 'Tipo de jurisdicción', 'Tipo de jurisdicción', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', 'c', 'Otra designación', 'Otra designación', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', 'd', 'Título de persona', 'Título de persona', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', 's', 'Período de inicio', 'Período de inicio', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', 't', 'Fin de período', 'Fin de período', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', '2', 'Fuente', 'Fuente', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '368', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 'a', 'Lugar de nacimiento', 'Lugar de nacimiento', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 'b', 'Lugar de fallecimiento', 'Lugar de fallecimiento', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 'c', 'País asociado', 'País asociado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 'e', 'Lugar de residencia/sede', 'Lugar de residencia/sede', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 'f', 'Otro lugar asociado', 'Otro lugar asociado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 'g', 'Lugar de origen de la obra', 'Lugar de origen de la obra', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 's', 'Período de inicio', 'Período de inicio', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 't', 'Fin de período', 'Fin de período', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '370', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 'a', 'Dirección', 'Dirección', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 'b', 'Ciudad', 'Ciudad', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 'c', 'Jurisdicción secundaria/intermedia', 'Jurisdicción secundaria/intermedia', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 'd', 'País', 'País', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 'e', 'Código postal', 'Código postal', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 'm', 'Dirección de correo electrónico', 'Dirección de correo electrónico', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 's', 'Período de inicio', 'Período de inicio', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 't', 'Fin de período', 'Fin de período', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', 'z', 'Nota pública', 'Nota pública', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', '4', 'Código de función/relación', 'Código de función/relación', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '371', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '372', 'a', 'Campo de actividad', 'Campo de actividad', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '372', 's', 'Período de inicio', 'Período de inicio', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '372', 't', 'Fin de período', 'Fin de período', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '372', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '372', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '372', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '372', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '372', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '372', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '373', 'a', 'Grupo asociado', 'Grupo asociado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '373', 's', 'Período de inicio', 'Período de inicio', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '373', 't', 'Fin de período', 'Fin de período', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '373', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '373', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '373', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '373', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '373', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '373', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '374', 'a', 'Ocupación', 'Ocupación', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '374', 's', 'Período de inicio', 'Período de inicio', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '374', 't', 'Fin de período', 'Fin de período', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '374', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '374', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '374', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '374', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '374', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '374', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '375', 'a', 'Género/Sexo', 'Género/Sexo', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '375', 's', 'Período de inicio', 'Período de inicio', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '375', 't', 'Fin de período', 'Fin de período', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '375', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '375', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '375', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '375', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '375', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', 'a', 'Tipo de familia', 'Tipo de familia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', 'b', 'Nombre de miembro prominente', 'Nombre de miembro prominente', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', 'c', 'Título hereditario', 'Título hereditario', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', 's', 'Período de inicio', 'Período de inicio', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', 't', 'Fin de período', 'Fin de período', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '376', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '377', 'a', 'Código del idioma', 'Código del idioma', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '377', 'l', 'Término de lengua/lenguaje', 'Término de lengua/lenguaje', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '377', '2', 'Fuente del código', 'Fuente del código', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '377', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '377', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '378', 'q', 'Forma completa/desarrollada del nombre', 'Forma completa/desarrollada del nombre', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '378', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '378', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '378', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '378', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '380', 'a', 'Forma de la obra', 'Forma de la obra', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '380', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '380', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '380', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '380', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '381', 'a', 'Otras características distintivas', 'Otras características distintivas', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '381', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '381', 'v', 'Fuente de información', 'Fuente de información', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '381', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '381', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '381', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '381', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 'a', 'Medio de interpretación', 'Medio de interpretación', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 'b', 'Solista', 'Solista', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 'd', 'Instrumento auxiliar', 'Instrumento auxiliar', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 'e', 'Número de conjuntos de un mismo medio', 'Número de conjuntos de un mismo medio', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 'n', 'Número de intérpretes de un mismo medio', 'Número de intérpretes de un mismo medio', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 'p', 'Medio de interpretación alternativo', 'Medio de interpretación alternativo', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 'r', 'Número total de individuos que interpretan junto a los conjuntos', 'Número total de individuos que interpretan junto a los conjuntos', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 's', 'Número total de intérpretes', 'Número total de intérpretes', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 't', 'Número total de conjuntos', 'Número total de conjuntos', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', 'v', 'Nota', 'Nota', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '382', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '383', 'a', 'Número de serie', 'Número de serie', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '383', 'b', 'Número de opus', 'Número de opus', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '383', 'c', 'Número de catálogo temático', 'Número de catálogo temático', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '383', 'd', 'Código de catálogo temático', 'Código de catálogo temático', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '383', 'e', 'Editor asociado al número de serie o de opus', 'Editor asociado al número de serie o de opus', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '383', '2', 'Fuente', 'Fuente', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '383', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '383', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '384', 'a', 'Tonalidad/Clave', 'Tonalidad/Clave', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '384', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '384', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '385', 'a', 'Término para el público', 'Término para el público', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '385', 'b', 'Código para el público', 'Código para el público', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '385', 'm', 'Término para el grupo demográfico', 'Término para el grupo demográfico', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '385', 'n', 'Código para el grupo demográfico', 'Código para el grupo demográfico', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '385', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '385', '2', 'Fuente', 'Fuente', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '385', '3', 'Especificación de materiales', 'Especificación de materiales', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '385', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '385', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '386', 'a', 'Término para el creador/colaborador', 'Término para el creador/colaborador', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '386', 'b', 'Código para el creador/colaborador', 'Código para el creador/colaborador', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '386', 'm', 'Término para el grupo demográfico', 'Término para el grupo demográfico', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '386', 'n', 'Código para el grupo demográfico', 'Código para el grupo demográfico', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '386', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '386', '2', 'Fuente', 'Fuente', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '386', '3', 'Especificación de materiales', 'Especificación de materiales', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '386', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '386', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '388', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '388', '2', 'Fuente del término', 'Fuente del término', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '388', '3', 'Especificación de materiales', 'Especificación de materiales', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '388', '6', 'Enlace', 'Enlace', 0, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '388', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '388', 'a', 'Término para el periodo temporal de creación', 'Término para el periodo temporal de creación', 1, 0, 3, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'a', 'Nombre de persona', 'Nombre de persona', 0, 0, 4, NULL, NULL, '''400b'',''400c'',''400q'',''400d'',''400t'',''400o'',''400m'',''400r'',''400s'',''400k'',''400n'',''400p'',''400g'',''400l'',''400f'',''400h'',''400x'',''400z'',''400y'',''400v''', 0, 0, 0, '', 'PERSO_NAME'),
		('', '400', 'b', 'Numeración', 'Numeración', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'c', 'Títulos y otros términos asociados al nombre', 'Títulos y otros términos asociados al nombre', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'd', 'Fechas asociadas al nombre', 'Fechas asociadas al nombre', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'e', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'h', 'Medio', 'Medio', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'j', 'Calificador de atribución', 'Calificador de atribución', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'n', 'Número de parte o sección de la obra', 'Número de parte o sección de la obra', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'q', 'Forma completa/desarrollada del nombre', 'Forma completa/desarrollada del nombre', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'r', 'Clave para música', 'Clave para música', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 's', 'Versión', 'Versión', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 't', 'Título de la obra', 'Título de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '400', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '410', 'a', 'Nombre de entidad corporativa o nombre de jurisdicción como elemento de entrada', 'Nombre de entidad corporativa o nombre de jurisdicción como elemento de entrada', 0, 0, 4, NULL, NULL, '''410b'',''410c'',''410d'',''410t'',''410o'',''410m'',''410r'',''410s'',''410k'',''410n'',''410p'',''410g'',''410l'',''410f'',''410h'',''410x'',''410z'',''410y'',''410v''', 0, 0, 0, '', 'CORPO_NAME'),
		('', '410', 'b', 'Unidad subordinada', 'Unidad subordinada', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'c', 'Sede del congreso/Lugar de la reunión', 'Sede del congreso/Lugar de la reunión', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'd', 'Fecha del congreso/reunión o de la firma de un tratado', 'Fecha del congreso/reunión o de la firma de un tratado', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'e', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'h', 'Medio', 'Medio', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'n', 'Número del congreso/reunión o número de parte o sección', 'Número del congreso/reunión o número de parte o sección', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'r', 'Clave para música', 'Clave para música', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 's', 'Versión', 'Versión', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 't', 'Título de la obra', 'Título de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '410', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '411', 'a', 'Nombre de congreso/reunión o jurisdicción como elemento de entrada', 'Nombre de congreso/reunión o jurisdicción como elemento de entrada', 0, 0, 4, NULL, NULL, '''411e'',''411c'',''411d'',''411t'',''411s'',''411k'',''411n'',''411p'',''411g'',''411l'',''411f'',''411h'',''411x'',''411z'',''411y'',''411v''', 0, 0, 0, '', 'MEETI_NAME'),
		('', '411', 'b', 'Número {OBOSLETO]', 'Número {OBOSLETO]', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'c', 'Sede del congreso/Lugar de la reunión', 'Sede del congreso/Lugar de la reunión', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'd', 'Fecha del congreso/reunión', 'Fecha del congreso/reunión', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'e', 'Unidad subordinada', 'Unidad subordinada', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'h', 'Medio', 'Medio', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'j', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'n', 'Número del congreso/reunión o número de parte o sección', 'Número del congreso/reunión o número de parte o sección', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'q', 'Nombre de congreso/reunión que sigue a un nombre de jurisdicción como elemento de entrada', 'Nombre de congreso/reunión que sigue a un nombre de jurisdicción como elemento de entrada', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 's', 'Versión', 'Versión', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 't', 'Título de la obra', 'Título de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '411', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '430', 'a', 'Título uniforme', 'Título uniforme', 0, 0, 4, NULL, NULL, '''430o'',''430m'',''430r'',''430s'',''430d'',''430k'',''430n'',''430p'',''430g'',''430l'',''430f'',''430h'',''430t'',''430x'',''430z'',''430y'',''430v''', 0, 0, 0, '', 'UNIF_TITLE'),
		('', '430', 'd', 'Fecha de la firma de un tratado', 'Fecha de la firma de un tratado', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'h', 'Medio', 'Medio', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'n', 'Número de parte o sección de la obra', 'Número de parte o sección de la obra', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'r', 'Clave para música', 'Clave para música', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 's', 'Versión', 'Versión', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 't', 'Título de la obra', 'Título de la obra', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '430', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '448', 'a', 'Término cronológico', 'Término cronológico', 0, 0, 4, NULL, NULL, '''448y'',''448x'',''448z'',''448v''', 0, 0, 0, '', 'CHRON_TERM'),
		('', '448', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '448', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '450', 'a', 'Término de materia o nombre geográfico como elemento de entrada', 'Término de materia o nombre geográfico como elemento de entrada', 0, 0, 4, NULL, NULL, '''450x'',''450z'',''450y'',''450v''', 0, 0, 0, '', 'TOPIC_TERM'),
		('', '450', 'b', 'Término de materia que sigue a un nombre geográfico como elemento de entrada', 'Término de materia que sigue a un nombre geográfico como elemento de entrada', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '450', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '451', 'a', 'Nombre geográfico', 'Nombre geográfico', 0, 0, 4, NULL, NULL, '''451z'',''451x'',''451y'',''451v''', 0, 0, 0, '', 'GEOGR_NAME'),
		('', '451', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '451', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '453', 'a', 'Número de clasificación--Único número o número inicial del rango', 'Número de clasificación--Único número o número inicial del rango', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', 'c', 'Elemento de clasificación-Último número del rango', 'Elemento de clasificación-Último número del rango', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', 'h', 'Jerarquía de epígrafe', 'Jerarquía de epígrafe', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', 'j', 'Epígrafe', 'Epígrafe', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', 'k', 'Número sumario rango de jerarquía de epígrafe', 'Número sumario rango de jerarquía de epígrafe', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', 't', 'Tema', 'Tema', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', 'y', 'Tabla de identificación--Esquema [OBSOLETO]', 'Tabla de identificación--Esquema [OBSOLETO]', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', 'z', 'Identificador de tabla', 'Identificador de tabla', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '453', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '455', 'a', 'Término de género/forma', 'Término de género/forma', 0, 0, 4, NULL, NULL, '''455v'',''455x'',''455z'',''455y''', 0, 0, 0, '', 'GENRE/FORM'),
		('', '455', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '455', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 4, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '462', 'a', 'Término de medio de interpretación', 'Término de medio de interpretación', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '462', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '462', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '462', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '462', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '462', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '462', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '480', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '481', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '482', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', '4', 'Código de relación', 'Código de relación', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', '6', 'Enlace', 'Enlace', 0, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '485', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 4, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'a', 'Nombre de persona', 'Nombre de persona', 0, 0, 5, NULL, NULL, '''500b'',''500c'',''500q'',''500d'',''500t'',''500o'',''500m'',''500r'',''500s'',''500k'',''500n'',''500p'',''500g'',''500l'',''500f'',''500h'',''500x'',''500z'',''500y'',''500v''', 0, 0, 0, '', 'PERSO_NAME'),
		('', '500', 'b', 'Numeración', 'Numeración', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'c', 'Títulos y otros términos asociados al nombre', 'Títulos y otros términos asociados al nombre', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'd', 'Fechas asociadas al nombre', 'Fechas asociadas al nombre', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'e', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'h', 'Medio', 'Medio', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'j', 'Calificador de atribución', 'Calificador de atribución', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'n', 'Número de parte o sección de la obra', 'Número de parte o sección de la obra', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'q', 'Forma completa/desarrollada del nombre', 'Forma completa/desarrollada del nombre', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'r', 'Clave para música', 'Clave para música', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 's', 'Versión', 'Versión', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 't', 'Título de la obra', 'Título de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '500', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '510', 'a', 'Nombre de entidad corporativa o nombre de jurisdicción como elemento de entrada', 'Nombre de entidad corporativa o nombre de jurisdicción como elemento de entrada', 0, 0, 5, NULL, NULL, '''510b'',''510c'',''510d'',''510t'',''510o'',''510m'',''510r'',''510s'',''510k'',''510n'',''510p'',''510g'',''510l'',''510f'',''510h'',''510x'',''510z'',''510y'',''510v''', 0, 0, 0, '', 'CORPO_NAME'),
		('', '510', 'b', 'Unidad subordinada', 'Unidad subordinada', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'c', 'Sede del congreso/Lugar de la reunión', 'Sede del congreso/Lugar de la reunión', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'd', 'Fecha del congreso/reunión o de la firma de un tratado', 'Fecha del congreso/reunión o de la firma de un tratado', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'e', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'h', 'Medio', 'Medio', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'n', 'Número del congreso/reunión o número de parte o sección', 'Número del congreso/reunión o número de parte o sección', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'r', 'Clave para música', 'Clave para música', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 's', 'Versión', 'Versión', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 't', 'Título de la obra', 'Título de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '510', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '511', 'a', 'Nombre de congreso/reunión o jurisdicción como elemento de entrada', 'Nombre de congreso/reunión o jurisdicción como elemento de entrada', 0, 0, 5, NULL, NULL, '''511e'',''511c'',''511d'',''511t'',''511s'',''511k'',''511n'',''511p'',''511g'',''511l'',''511f'',''511h'',''511x'',''511z'',''511y'',''511v''', 0, 0, 0, '', 'MEETI_NAME'),
		('', '511', 'c', 'Sede del congreso/Lugar de la reunión', 'Sede del congreso/Lugar de la reunión', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'd', 'Fecha del congreso/reunión', 'Fecha del congreso/reunión', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'e', 'Unidad subordinada', 'Unidad subordinada', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'h', 'Medio', 'Medio', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'j', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'n', 'Número del congreso/reunión o número de parte o sección', 'Número del congreso/reunión o número de parte o sección', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'q', 'Nombre de congreso/reunión que sigue a un nombre de jurisdicción como elemento de entrada', 'Nombre de congreso/reunión que sigue a un nombre de jurisdicción como elemento de entrada', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 's', 'Versión', 'Versión', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 't', 'Título de la obra', 'Título de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '511', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '530', 'a', 'Título uniforme', 'Título uniforme', 0, 0, 5, NULL, NULL, '''530o'',''530m'',''530r'',''530s'',''530d'',''530k'',''530n'',''530p'',''530g'',''530l'',''530f'',''530h'',''530t'',''530x'',''530z'',''530y'',''530v''', 0, 0, 0, '', 'UNIF_TITLE'),
		('', '530', 'd', 'Fecha de la firma de un tratado', 'Fecha de la firma de un tratado', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'h', 'Medio', 'Medio', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'n', 'Número de parte o sección de la obra', 'Número de parte o sección de la obra', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'r', 'Clave para música', 'Clave para música', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 's', 'Versión', 'Versión', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 't', 'Título de la obra', 'Título de la obra', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '530', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '548', 'a', 'Término cronológico', 'Término cronológico', 0, 0, 5, NULL, NULL, '''548y'',''548x'',''548z'',''548v''', 0, 0, 0, '', 'CHRON_TERM'),
		('', '548', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '548', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '550', 'a', 'Término de materia o nombre geográfico como elemento de entrada', 'Término de materia o nombre geográfico como elemento de entrada', 0, 0, 5, NULL, NULL, '''550x'',''550z'',''550y'',''550v''', 0, 0, 0, '', 'TOPIC_TERM'),
		('', '550', 'b', 'Término de materia que sigue a un nombre geográfico como elemento de entrada', 'Término de materia que sigue a un nombre geográfico como elemento de entrada', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '550', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '551', 'a', 'Nombre geográfico', 'Nombre geográfico', 0, 0, 5, NULL, NULL, '''551z'',''551x'',''551y'',''551v''', 0, 0, 0, '', 'GEOGR_NAME'),
		('', '551', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '551', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '553', 'a', 'Número de clasificación--Único número o número inicial del rango', 'Número de clasificación--Único número o número inicial del rango', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', 'c', 'Número de clasificación--Último número del rango', 'Número de clasificación--Último número del rango', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', 'h', 'Jerarquía de epígrafe', 'Jerarquía de epígrafe', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', 'j', 'Epígrafe', 'Epígrafe', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', 'k', 'Número sumario rango de jerarquía de epígrafe', 'Número sumario rango de jerarquía de epígrafe', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', 't', 'Tema', 'Tema', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', 'y', 'Tabla de identificación--Esquema [OBSOLETO]', 'Tabla de identificación--Esquema [OBSOLETO]', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', 'z', 'Identificador de tabla', 'Identificador de tabla', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '553', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '555', 'a', 'Término de género/forma', 'Término de género/forma', 0, 0, 5, NULL, NULL, '''555v'',''555x'',''555z'',''555y''', 0, 0, 0, '', 'GENRE/FORM'),
		('', '555', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '555', '9', '9 (RLIN)', '9 (RLIN)', 0, 0, 5, NULL, NULL, NULL, 0, 1, 0, '', ''),
		('', '562', 'a', 'Término de medio de interpretación', 'Término de medio de interpretación', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '562', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '562', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '562', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '562', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '562', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '562', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '562', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '580', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '581', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '582', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', '4', 'Código de relación', 'Código de relación', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', '6', 'Enlace', 'Enlace', 0, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '585', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 5, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '640', 'a', 'Fecha de publicación y/o designación secuencial', 'Fecha de publicación y/o designación secuencial', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '640', 'z', 'Fuente de información', 'Fuente de información', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '640', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '640', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '641', 'a', 'Nota de peculiaridades de la numeración', 'Nota de peculiaridades de la numeración', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '641', 'z', 'Fuente de información', 'Fuente de información', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '641', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '641', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '642', 'a', 'Ejemplo de numeración de serie', 'Ejemplo de numeración de serie', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '642', 'd', 'Volúmenes/fechas a los que aplica los ejemplos de numeración de serie', 'Volúmenes/fechas a los que aplica los ejemplos de numeración de serie', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '642', '5', 'Institución/copia que aplica el campo', 'Institución/copia que aplica el campo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '642', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '642', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '643', 'a', 'Lugar', 'Lugar', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '643', 'b', 'Entidad editora/emisora', 'Entidad editora/emisora', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '643', 'd', 'Volúmenes/fechas a los que aplica el lugar y entidad editora/emisora', 'Volúmenes/fechas a los que aplica el lugar y entidad editora/emisora', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '643', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '643', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '644', 'a', 'Práctica de análisis de serie', 'Práctica de análisis de serie', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '644', 'b', 'Excepción en la práctica de análisis', 'Excepción en la práctica de análisis', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '644', 'd', 'Volúmenes/fechas a los que aplica la práctica del análisis', 'Volúmenes/fechas a los que aplica la práctica del análisis', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '644', '5', 'Institución/copia que aplica el campo', 'Institución/copia que aplica el campo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '644', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '644', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '645', 'a', 'Práctica en el trazado de serie', 'Práctica en el trazado de serie', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '645', 'd', 'Volúmenes/fechas a los que aplica la práctica del trazado', 'Volúmenes/fechas a los que aplica la práctica del trazado', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '645', '5', 'Institución/copia que aplica el campo', 'Institución/copia que aplica el campo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '645', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '645', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '646', 'a', 'Práctica de clasificación de la serie', 'Práctica de clasificación de la serie', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '646', 'd', 'Volúmenes/fechas a los que aplica la práctica de clasificación', 'Volúmenes/fechas a los que aplica la práctica de clasificación', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '646', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '646', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '646', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '663', 'a', 'Texto explicativo', 'Texto explicativo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '663', 'b', 'Encabezamiento referido a', 'Encabezamiento referido a', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '663', 't', 'Título referido a', 'Título referido a', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '663', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '663', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '664', 'a', 'Texto explicativo', 'Texto explicativo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '664', 'b', 'Encabezamiento referido a', 'Encabezamiento referido a', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '664', 't', 'Título referido a', 'Título referido a', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '664', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '664', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '665', 'a', 'Referencia histórica', 'Referencia histórica', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '665', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '665', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '666', 'a', 'Referencia explicativa general', 'Referencia explicativa general', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '666', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '666', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '667', 'a', 'Nota general no pública', 'Nota general no pública', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '667', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '667', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '667', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '668', 'a', 'Caracteres en alfabeto no latino', 'Caracteres en alfabeto no latino', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '670', 'a', 'Cita de la fuente', 'Cita de la fuente', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '670', 'b', 'Información encontrada', 'Información encontrada', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '670', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '670', 'w', 'Número de control del registro bibliográfico', 'Número de control del registro bibliográfico', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '670', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '670', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '671', 'a', 'Cita bibliográfica', 'Cita bibliográfica', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '671', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '672', 'a', 'Título', 'Título', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '672', 'b', 'Resto del título', 'Resto del título', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '672', 'f', 'Fecha', 'Fecha', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '672', 'w', 'Número de control del registro bibliográfico', 'Número de control del registro bibliográfico', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '672', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '672', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '672', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '673', 'a', 'Título', 'Título', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '673', 'b', 'Resto del título', 'Resto del título', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '673', 'f', 'Fecha', 'Fecha', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '673', 'w', 'Número de control del registro bibliográfico', 'Número de control del registro bibliográfico', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '673', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '673', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '673', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '675', 'a', 'Cita de la fuente', 'Cita de la fuente', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '675', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '675', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '676', 'a', 'Número de regla(s) e información adicional', 'Número de regla(s) e información adicional', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '676', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '678', 'a', 'Datos biográficos o históricos', 'Datos biográficos o históricos', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '678', 'b', 'Ampliación de la nota', 'Ampliación de la nota', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '678', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '678', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '678', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '680', 'a', 'Encabezamiento o término de subdivisión', 'Encabezamiento o término de subdivisión', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '680', 'c', 'Número de clasificación--Último número del rango [FORMATO DE CLASIFICACIÓN]', 'Número de clasificación--Último número del rango [FORMATO DE CLASIFICACIÓN]', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '680', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '680', 'z', 'Identificador de tabla', 'Identificador de tabla', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '680', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '680', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '680', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '681', 'a', 'Encabezamiento de materia o término de subdivisión', 'Encabezamiento de materia o término de subdivisión', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '681', 'c', 'Número de clasificación--Último número del rango [FORMATO DE CLASIFICACIÓN]', 'Número de clasificación--Último número del rango [FORMATO DE CLASIFICACIÓN]', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '681', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '681', 'z', 'Identificador de tabla', 'Identificador de tabla', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '681', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '681', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '682', 'a', 'Encabezamiento de reemplazo', 'Encabezamiento de reemplazo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '682', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '682', '0', 'Número de control de registro de autoridad de reemplazo', 'Número de control de registro de autoridad de reemplazo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '682', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '682', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '683', 'a', 'Número de clasificación--Único número o número inicial del rango', 'Número de clasificación--Único número o número inicial del rango', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '683', 'c', 'Número de clasificación--Último número del rango', 'Número de clasificación--Último número del rango', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '683', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '683', 'p', 'Campo de clasificación correspondiente', 'Campo de clasificación correspondiente', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '683', 'y', 'Tabla de identificación--Esquema [OBSOLETO]', 'Tabla de identificación--Esquema [OBSOLETO]', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '683', 'z', 'Identificador de tabla', 'Identificador de tabla', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '683', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '683', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '683', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '684', 'a', 'Número de clasificación--Único número o número inicial del rango', 'Número de clasificación--Único número o número inicial del rango', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '684', 'c', 'Número de clasificación--Último número del rango', 'Número de clasificación--Último número del rango', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '684', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '684', 'j', 'Epígrafe', 'Epígrafe', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '684', 'z', 'Identificador de tabla', 'Identificador de tabla', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '684', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '684', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '684', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '685', 'a', 'Fuente consultada e información encontrada', 'Fuente consultada e información encontrada', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '685', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '686', 'a', 'Fuente consultada e información encontrada', 'Fuente consultada e información encontrada', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '686', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '687', 'a', 'Fuente consultada e información encontrada', 'Fuente consultada e información encontrada', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '687', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '688', 'a', 'Nota de historia de la aplicación', 'Nota de historia de la aplicación', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '688', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '688', '6', 'Enlace', 'Enlace', 0, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '688', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 6, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'a', 'Nombre de persona', 'Nombre de persona', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'b', 'Numeración', 'Numeración', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'c', 'Títulos y otros términos asociados al nombre', 'Títulos y otros términos asociados al nombre', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'd', 'Fechas asociadas al nombre', 'Fechas asociadas al nombre', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'e', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'h', 'Medio', 'Medio', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'j', 'Calificador de atribución', 'Calificador de atribución', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'n', 'Número de parte o sección de la obra', 'Número de parte o sección de la obra', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'q', 'Forma completa/desarrollada del nombre', 'Forma completa/desarrollada del nombre', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'r', 'Clave para música', 'Clave para música', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 's', 'Versión', 'Versión', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 't', 'Título de la obra', 'Título de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', '3', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '700', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'a', 'Nombre de entidad corporativa o nombre de jurisdicción como elemento de entrada', 'Nombre de entidad corporativa o nombre de jurisdicción como elemento de entrada', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'b', 'Unidad subordinada', 'Unidad subordinada', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'c', 'Sede del congreso/Lugar de la reunión', 'Sede del congreso/Lugar de la reunión', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'd', 'Fecha del congreso/reunión o de la firma de un tratado', 'Fecha del congreso/reunión o de la firma de un tratado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'e', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'h', 'Medio', 'Medio', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'n', 'Número del congreso/reunión o número de parte o sección', 'Número del congreso/reunión o número de parte o sección', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'r', 'Clave para música', 'Clave para música', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 's', 'Versión', 'Versión', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 't', 'Título de la obra', 'Título de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', '3', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '710', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'a', 'Nombre de congreso/reunión o jurisdicción como elemento de entrada', 'Nombre de congreso/reunión o jurisdicción como elemento de entrada', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'c', 'Sede del congreso/Lugar de la reunión', 'Sede del congreso/Lugar de la reunión', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'd', 'Fecha del congreso/reunión', 'Fecha del congreso/reunión', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'e', 'Unidad subordinada', 'Unidad subordinada', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'g', 'Información miscelánea', 'Información miscelánea', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'h', 'Medio', 'Medio', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'j', 'Término indicativo de función/relación', 'Término indicativo de función/relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'n', 'Número del congreso/reunión o número de parte o sección', 'Número del congreso/reunión o número de parte o sección', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'q', 'Nombre de congreso/reunión que sigue a un nombre de jurisdicción como elemento de entrada', 'Nombre de congreso/reunión que sigue a un nombre de jurisdicción como elemento de entrada', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 's', 'Versión', 'Versión', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 't', 'Título de la obra', 'Título de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', '3', 'Especificación de materiales', 'Especificación de materiales', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '711', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'a', 'Título uniforme', 'Título uniforme', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'd', 'Fecha de la firma de un tratado', 'Fecha de la firma de un tratado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'f', 'Fecha de publicación/de la obra', 'Fecha de publicación/de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'h', 'Medio', 'Medio', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'k', 'Subencabezamiento de forma', 'Subencabezamiento de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'l', 'Lenguaje de la obra', 'Lenguaje de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'm', 'Medio de interpretación para música', 'Medio de interpretación para música', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'n', 'Número de parte o sección de la obra', 'Número de parte o sección de la obra', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'o', 'Mención de arreglo para música', 'Mención de arreglo para música', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'p', 'Nombre de parte o sección de la obra', 'Nombre de parte o sección de la obra', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'r', 'Clave para música', 'Clave para música', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 's', 'Versión', 'Versión', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 't', 'Título de la obra', 'Título de la obra', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', '3', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '730', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', 'a', 'Término cronológico', 'Término cronológico', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', '3', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '748', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'a', 'Término de materia o nombre geográfico como elemento de entrada', 'Término de materia o nombre geográfico como elemento de entrada', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'b', 'Término de materia que sigue a un nombre geográfico como elemento de entrada', 'Término de materia que sigue a un nombre geográfico como elemento de entrada', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'c', 'Localización del acontecimiento', 'Localización del acontecimiento', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'd', 'Fecha vigente/activa', 'Fecha vigente/activa', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', '3', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '750', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', 'a', 'Nombre geográfico', 'Nombre geográfico', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', 'g', 'Información miscelánea', 'Información miscelánea', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', '3', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 'Especificación de materiales [FORMATO DE CLASIFICACIÓN]', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '751', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', 'a', 'Término del índice', 'Término del índice', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', 'b', 'Término de índice--Nivel subsiguiente', 'Término de índice--Nivel subsiguiente', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', 'd', 'Término del índice referido de', 'Término del índice referido de', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', 'e', 'Ejemplo de número de clasificación', 'Ejemplo de número de clasificación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', 's', 'Término de referencia de véase además', 'Término de referencia de véase además', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', 't', 'Término de referencia de véase además--Nivel subsiguiente', 'Término de referencia de véase además--Nivel subsiguiente', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', 'u', 'Uso de término de referencia', 'Uso de término de referencia', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', 'v', 'Uso de término de referencia--Nivel subsiguiente', 'Uso de término de referencia--Nivel subsiguiente', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '753', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', 'a', 'Término principal', 'Término principal', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', 'b', 'Término no-principal', 'Término no-principal', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', 'c', 'Designación de faceta/jerarquía', 'Designación de faceta/jerarquía', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', '3', 'Especificación de materiales', 'Especificación de materiales', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '754', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', 'a', 'Término género/forma como elemento de entrada', 'Término género/forma como elemento de entrada', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '755', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'a', 'Número donde se han tomado las instrucciones--Único número o número inicial del rango', 'Número donde se han tomado las instrucciones--Único número o número inicial del rango', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'b', 'Número base', 'Número base', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'c', 'Número de clasificación--Último número del rango', 'Número de clasificación--Último número del rango', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'd', 'Número de dividido como', 'Número de dividido como', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'e', 'Ejemplo de número de clasificación', 'Ejemplo de número de clasificación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'f', 'Indicador de faceta', 'Indicador de faceta', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'n', 'Ejemplo negativo de número de clasificación', 'Ejemplo negativo de número de clasificación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'r', 'Número raíz', 'Número raíz', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'x', 'Otro número de clasificación', 'Otro número de clasificación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', 'z', 'Identificador de tabla', 'Identificador de tabla', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '761', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', 'a', 'Término de medio de interpretación como elemento de entrada', 'Término de medio de interpretación como elemento de entrada', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', 'z', 'Número de tabla', 'Número de tabla', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '762', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'a', 'Número de clasificación--Único número o número inicial del rango', 'Número de clasificación--Único número o número inicial del rango', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'b', 'Número base', 'Número base', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'c', 'Número de clasificación--Último número del rango', 'Número de clasificación--Último número del rango', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'd', 'Número de dividido como', 'Número de dividido como', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'e', 'Ejemplo de número de clasificación', 'Ejemplo de número de clasificación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'h', 'Jerarquía de epígrafe', 'Jerarquía de epígrafe', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'j', 'Epígrafe', 'Epígrafe', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'k', 'Número sumario rango de jerarquía de epígrafe', 'Número sumario rango de jerarquía de epígrafe', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'm', 'Nota del manual', 'Nota del manual', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'n', 'Número donde se han encontrado las instrucciones', 'Número donde se han encontrado las instrucciones', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'p', 'Campo de clasificación correspondiente', 'Campo de clasificación correspondiente', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'r', 'Número raíz', 'Número raíz', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 's', 'Referencia de véase', 'Referencia de véase', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'x', 'Otro número de clasificación', 'Otro número de clasificación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', 'z', 'Identificador de tabla', 'Identificador de tabla', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '763', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '764', 'a', 'Número donde se encuentran las instrucciones--Último número del rango', 'Número donde se encuentran las instrucciones--Último número del rango', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '764', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '764', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '764', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'a', 'Número donde las instrucciones se encontraron--Único número o número inicial del rango', 'Número donde las instrucciones se encontraron--Único número o número inicial del rango', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'b', 'Número base', 'Número base', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'c', 'Número donde se encuentran las instrucciones--Último número del rango', 'Número donde se encuentran las instrucciones--Último número del rango', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'f', 'Indicador de faceta', 'Indicador de faceta', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'r', 'Número raíz', 'Número raíz', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 's', 'Dígitos añadidos a partir de un número de clasificación de un esquema o tabla externa', 'Dígitos añadidos a partir de un número de clasificación de un esquema o tabla externa', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 't', 'Dígitos añadidos a partir de una subordenación interna o una tabla adicional', 'Dígitos añadidos a partir de una subordenación interna o una tabla adicional', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'u', 'Número que se analiza', 'Número que se analiza', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'v', 'Número de una subordenación interna o tabla adicional en el que se dan las pautas [de agregación]', 'Número de una subordenación interna o tabla adicional en el que se dan las pautas [de agregación]', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'w', 'Identificador de tabla--subarreglo interno o tabla adherida', 'Identificador de tabla--subarreglo interno o tabla adherida', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'y', 'Tabla de identificación--Esquema [OBSOLETO]', 'Tabla de identificación--Esquema [OBSOLETO]', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', 'z', 'Identificador de tabla', 'Identificador de tabla', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '765', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '766', 'a', 'Aplicabilidad de la tabla secundaria', 'Aplicabilidad de la tabla secundaria', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '766', 'y', 'Tipo de división', 'Tipo de división', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '766', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '766', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', 'a', 'Número de clasificación--Único número o número inicial del rango', 'Número de clasificación--Único número o número inicial del rango', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', 'c', 'Número de clasificación--Último número del rango', 'Número de clasificación--Último número del rango', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', 'e', 'Ejemplo de número de clasificación', 'Ejemplo de número de clasificación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', 'j', 'Epígrafe', 'Epígrafe', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', 'n', 'Ejemplo negativo de número de clasificación', 'Ejemplo negativo de número de clasificación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', 't', 'Tópico usado como ejemplo de la citación e instrucción en orden de preferencia', 'Tópico usado como ejemplo de la citación e instrucción en orden de preferencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', 'x', 'Excepción a la tabla de preferencia', 'Excepción a la tabla de preferencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', 'z', 'Identificación de tabla--Número de tabla', 'Identificación de tabla--Número de tabla', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '768', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '780', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '781', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '782', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', 'i', 'Información de relación/Frase instructiva de referencia', 'Información de relación/Frase instructiva de referencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', 'v', 'Subdivisión de forma', 'Subdivisión de forma', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', 'w', 'Subcampo de control', 'Subcampo de control', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', 'x', 'Subdivisión general', 'Subdivisión general', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', 'y', 'Subdivisión cronológica', 'Subdivisión cronológica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', 'z', 'Subdivisión geográfica', 'Subdivisión geográfica', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '785', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '788', 'a', 'Encabezamiento referido a', 'Encabezamiento referido a', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '788', 'i', 'Texto explicativo', 'Texto explicativo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '788', '0', 'Número de control del registro', 'Número de control del registro', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '788', '2', 'Fuente del encabezamiento o término', 'Fuente del encabezamiento o término', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '788', '4', 'Código de relación', 'Código de relación', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '788', '5', 'Institución que aplica el campo', 'Institución que aplica el campo', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '788', '6', 'Enlace', 'Enlace', 0, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '788', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 7, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'a', 'Nombre del host', 'Nombre del host', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'b', 'Número de acceso', 'Número de acceso', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'c', 'Información sobre la compresión', 'Información sobre la compresión', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'd', 'Ruta', 'Ruta', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'f', 'Nombre electrónico', 'Nombre electrónico', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'h', 'Procesador de la petición', 'Procesador de la petición', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'i', 'Instrucción', 'Instrucción', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'j', 'Bits por segundo', 'Bits por segundo', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'k', 'Contraseña', 'Contraseña', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'l', 'Proceso de conexión (Logon)', 'Proceso de conexión (Logon)', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'm', 'Contacto para facilitar el acceso', 'Contacto para facilitar el acceso', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'n', 'Nombre de la localización del host', 'Nombre de la localización del host', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'o', 'Sistema operativo', 'Sistema operativo', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'p', 'Puerto', 'Puerto', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'q', 'Tipo de formato electrónico', 'Tipo de formato electrónico', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'r', 'Parámetros', 'Parámetros', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 's', 'Tamaño de archivo', 'Tamaño de archivo', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 't', 'Emulación del terminal', 'Emulación del terminal', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'v', 'Horario en que el acceso está disponible', 'Horario en que el acceso está disponible', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'w', 'Número de control del registro', 'Número de control del registro', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'x', 'Nota interna', 'Nota interna', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'y', 'Texto de enlace', 'Texto de enlace', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', 'z', 'Nota pública', 'Nota pública', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', '2', 'Método de acceso', 'Método de acceso', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', '3', 'Especificación de materiales', 'Especificación de materiales', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', '6', 'Enlace', 'Enlace', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '856', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'a', 'a', 'a', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'b', 'b', 'b', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'c', 'c', 'c', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'd', 'd', 'd', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'e', 'e', 'e', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'f', 'f', 'f', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'g', 'g', 'g', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'h', 'h', 'h', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'i', 'i', 'i', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'j', 'j', 'j', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'k', 'k', 'k', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'l', 'l', 'l', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'm', 'm', 'm', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'n', 'n', 'n', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'o', 'o', 'o', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'p', 'p', 'p', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'q', 'q', 'q', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'r', 'r', 'r', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 's', 's', 's', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 't', 't', 't', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'u', 'u', 'u', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'v', 'v', 'v', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'w', 'w', 'w', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'x', 'x', 'x', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'y', 'y', 'y', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', 'z', 'z', 'z', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '0', '0', '0', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '1', '1', '1', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '2', '2', '2', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '3', '3', '3', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '4', '4', '4', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '5', '5', '5', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '6', 'Enlace', 'Enlace', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '7', '7', '7', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '8', '8', '8', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '880', '9', '9', '9', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '883', 'a', 'Proceso de generación', 'Proceso de generación', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '883', 'c', 'Valor de confidencia', 'Valor de confidencia', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '883', 'd', 'Fecha de generación', 'Fecha de generación', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '883', 'q', 'Agencia que genera los datos', 'Agencia que genera los datos', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '883', 'x', 'Fecha final de validez', 'Fecha final de validez', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '883', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '883', 'w', 'Número de control del registro bibliográfico', 'Número de control del registro bibliográfico', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '883', '0', 'Número de control del registro de autoridad o número normalizado', 'Número de control del registro de autoridad o número normalizado', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '883', '8', 'Enlace entre campo y número de secuencia', 'Enlace entre campo y número de secuencia', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '884', 'a', 'Proceso de conversión', 'Proceso de conversión', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '884', 'g', 'Fecha de conversión', 'Fecha de conversión', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '884', 'k', 'Identificador de los metadatos originales', 'Identificador de los metadatos originales', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '884', 'q', 'Agencia que convierte los datos', 'Agencia que convierte los datos', 0, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
		('', '884', 'u', 'Identificador Uniforme del Recurso', 'Identificador Uniforme del Recurso', 1, 0, 8, NULL, NULL, NULL, 0, 0, 0, '', ''),
        ('', '942', 'a', 'Tipo auth Koha', 'Tipo auth Koha', 0, 1, 9, NULL, NULL, NULL, 0, 1, 0, 'auth_header.authtypecode', '');


-- ******************************************************

-- *******************************************************************
-- PERSONAL NAME AUTHORITY FIELDS/SUBFIELDS. XX0
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'PERSO_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ('110','111','130','148','150','151','155','162',
                     '180','181','182','185','034','640','641','642',
                     '643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'PERSO_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ('110','111','130','148','150','151','155','162',
                     '180','181','182','185','034','640','641','642',
                     '643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- CORPORATE NAME AUTHORITY FIELDS/SUBFIELDS. X10
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'CORPO_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','111','130','148','150','151','155','162',
                      '180','181','182','185','034','640','641','642',
                      '643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'CORPO_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','111','130','148','150','151','155','162',
                      '180','181','182','185','034','640','641','642',
                      '643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- MEETING NAME AUTHORITY FIELDS/SUBFIELDS. X11
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'MEETI_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','130','148','150','151','155','162',
                      '180','181','182','185','640','641','642','643',
                      '644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'MEETI_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','130','148','150','151','155','162',
                      '180','181','182','185','640','641','642','643',
                      '644','645','646');

-- ******************************************************

-- *******************************************************************
-- UNIFORM TITLE AUTHORITY FIELDS/SUBFIELDS. X30
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'UNIF_TITLE', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','148','150','151','155','162',
                      '180','181','182','185');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'UNIF_TITLE', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','148','150','151','155','162',
                      '180','181','182','185');

-- ******************************************************

-- *******************************************************************
-- CHRONOLOGICAL TERMS AUTHORITY FIELDS/SUBFIELDS. X48
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'CHRON_TERM', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','150','151','155','162',
                      '180','181','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'CHRON_TERM', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','150','151','155','162',
                      '180','181','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- TOPICAL TERMS AUTHORITY FIELDS/SUBFIELDS. X50
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'TOPIC_TERM', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','151','155','162',
                      '181','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'TOPIC_TERM', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','151','155','162',
                      '181','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- GEOGRAPHIC NAMES AUTHORITY FIELDS/SUBFIELDS. X51
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'GEOGR_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','155','162',
                      '180','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'GEOGR_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','155','162',
                      '180','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- GENRE/FORM TERMS AUTHORITY FIELDS/SUBFIELDS. X55
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'GENRE/FORM', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','151','162',
                      '180','181','182','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'GENRE/FORM', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','151','162',
                      '180','181','182','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************
