-- *******************************************************
--   KOHA  MARC 21 STANDARD DEFAULT AUTHORITY FRAMEWORKS
--
--        Revised to Update No. 21 (September 2015)
-- *******************************************************

-- ******************************************************
-- KOHA DEFAULT MARC 21 AUTHORITY TYPE.
-- ******************************************************

-- This authority type includes all fields and subfieds used by any
-- authority type.

INSERT INTO auth_types (authtypecode, authtypetext, auth_tag_to_report, summary) VALUES
		('', 'Grille par défaut', '', '');


-- ******************************************************
-- KOHA SUPPORTED STANDARD MARC 21 AUTHORITY TYPES.
-- ******************************************************

-- These authority types are supported for for guiding the cataloguer to
-- fill authorised values in Koha MARC bibliographic editor.


INSERT INTO auth_types (authtypecode, authtypetext, auth_tag_to_report, summary) VALUES
		('PERSO_NAME', 'Nom de personne', '100', 'Nom de personne'),
		('CORPO_NAME', 'Nom de collectivité', '110', 'Nom de collectivité'),
		('MEETI_NAME', 'Nom de réunion', '111', 'Nom de réunion'),
		('UNIF_TITLE', 'Titre uniforme', '130', 'Titre uniforme'),
		('CHRON_TERM', 'Terme chronologique', '148', 'Terme chronologique'),
		('TOPIC_TERM', 'Nom commun', '150', 'Nom commun'),
		('GEOGR_NAME', 'Nom géographique', '151', 'Nom géographique'),
		('GENRE/FORM', 'Terme de genre/forme', '155', 'Terme de genre/forme');


-- ******************************************************
-- KOHA UNSUPPORTED STANDARD MARC 21 AUTHORITY TYPES.
-- ******************************************************

-- These authority types are only supported for guiding the cataloguer to
-- fill authorised values in the Koha MARC bibliographic editor to the
-- extent that they have already been included in a primary authority type,
-- therefore, they have not yet been specified.
--
-- Minimal primary authorities including subdivisions may currently be
-- built by a script which uses the values in bibliographic records but
-- include no tracings and references which are necessarily not present
-- in bibliographic records.


-- INSERT INTO `auth_types` (`authtypecode`, `authtypetext`, `auth_tag_to_report`, `summary`) VALUES
--		('TOPIC_SUBD', 'General Topical Term Subdivision', '180', 'General Topical Term Subdivision'),
--		('GEOGR_SUBD', 'Geographic Subdivision', '181', 'Geographic Subdivision'),
--		('CHRON_SUBD', 'Chronological Subdivision', '182', 'Chronological Subdivision'),
--		('FORM_SUBDI', 'Form Subdivision', '185', 'Form Subdivision');



-- *****************************************************************
-- MARC 21 AUTHORITY FIELDS/SUBFIELDS AND COMMMONLY USED EXTENSIONS
-- *****************************************************************


-- No support for subfield visibility is yet provided by the Koha code
-- matching the column name 'hidden' in the bibliographic framework.
--
-- Needs checking for errors but probably tolerable for use on a production.
-- A server can be upgraded easily from later versions of this file.
--
-- In the absense of more column support for qualifying the relative
-- importance of subfields to the record editor, some modest modification of
-- the default framework is needed setting the not-useful non-Koha holdings
-- subfields to not managed in Koha.

-- MARC fields including letters as part of the field identifier are from RLIN
-- and should be expected to remain along with RLIN $% subfields.  RLIN has
-- been using letters in fields because there are not enough local use number
-- fields which have not already been specified for very large union catalogue
-- networks such as RLIN itself.

-- Fields ending in a or b are temporary placeholders for information from
-- a numeric value until a non-conflicting way to treat the content under the
-- proper original numeric field is adopted.  090 for LC call numbers is much
-- too common and important so 999 is also provided as a temporary place
-- holder until all Koha code for finding control fields has been changed from
-- a numeric test of < 10 to a regular expression match of m/^00/ to prevent
-- mistaken matching of fields with letters such as 09o if they were control
-- fields.

-- Fields and subfields which belong exclusively in a classification
-- framework have been marked '[CLASSIFICATION FRAMEWORK]'.  They are retained
-- or included here becuase some had been included previously and Koha does
-- not yet have a classification framework.


INSERT INTO `auth_tag_structure` (`authtypecode`, `tagfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `authorised_value`) VALUES

("","000","Guide","Guide","0","1",NULL),
("","001","Numéro de contrôle","Numéro de contrôle","0","1",NULL),
("","003","Identité du numéro de contrôle","Identité du numéro de contrôle","0","1",NULL),
("","005","Date et heure de la dernière transaction","Date et heure de la dernière transaction","0","1",NULL),
("","008","Éléments de données de longueur fixe","Éléments de données de longueur fixe","0","1",NULL),
("","010","Numéro de contrôle de la Library of Congress","Numéro de contrôle de la Library of Congress","0","0",NULL),
("","014","Liaison d'une notice bibliographique d'une publication en série ou d'un document en plusieurs parties","Liaison d'une notice bibliographique d'une publication en série ou d'un document en plusieurs parties","1","0",NULL),
("","016","Numéro de contrôle de l'agence bibliographique nationale","Numéro de contrôle de l'agence bibliographique nationale","1","0",NULL),
("","020","Numéro international normalisé des livres","Numéro international normalisé des livres","1","0",NULL),
("","022","Numéro international normalisé des publications en série","Numéro international normalisé des publications en série","1","0",NULL),
("","024","Autre numéro ou code normalisé","Autre numéro ou code normalisé","1","0",NULL),
("","031","Information relative aux incipits musicaux","Information relative aux incipits musicaux","1","0",NULL),
("","034","Données mathématiques codées sur les documents cartographiques","Données mathématiques codées sur les documents cartographiques","1","0",NULL),
("","035","Numéro de contrôle de système","Numéro de contrôle de système","1","0",NULL),
("","040","Source du catalogage","Source du catalogage","0","1",NULL),
("","042","Code d'authenticité","Code d'authenticité","0","0",NULL),
("","043","Code d'aire géographique","Code d'aire géographique","0","0",NULL),
("","045","Période de temps de la vedette","Période de temps de la vedette","0","0",NULL),
("","050","Cote de la Library of Congress","Cote de la Library of Congress","1","0",NULL),
("","052","Classification géographique","Classification géographique","1","0",NULL),
("","053","Indice de classification de la LC","Indice de classification de la LC","1","0",NULL),
("","055","Cote de Bibliothèque et Archives Canada","Cote de Bibliothèque et Archives Canada","1","0",NULL),
("","060","Cote de la National Library of Medicine","Cote de la National Library of Medicine","1","0",NULL),
("","065","Autre indice de classification","Autre indice de classification","1","0",NULL),
("","066","Jeux de caractères présents","Jeux de caractères présents","0","0",NULL),
("","070","Cote de la National Agricultural Library","Cote de la National Agricultural Library","1","0",NULL),
("","072","Code de catégorie de sujets","Code de catégorie de sujets","1","0",NULL),
("","073","Usage de la subdivision","Usage de la subdivision","0","0",NULL),
("","082","Cote de classification décimale Dewey","Cote de classification décimale Dewey","1","0",NULL),
("","083","Indice de classification décimale de Dewey","Indice de classification décimale de Dewey","1","0",NULL),
("","086","Cote du document officiel","Cote du document officiel","1","0",NULL),
("","087","Numéro de classification de document officiel","Numéro de classification de document officiel","1","0",NULL),
("","100","Vedette - Nom de personne","Vedette - Nom de personne","0","0",NULL),
("","110","Vedette - Nom de collectivité","Vedette - Nom de collectivité","0","0",NULL),
("","111","Vedette - Nom de réunion","Vedette - Nom de réunion","0","0",NULL),
("","130","Vedette - Titre uniforme","Vedette - Titre uniforme","0","0",NULL),
("","148","Vedette - Terme chronologique","Vedette - Terme chronologique","0","0",NULL),
("","150","Vedette - Nom commun","Vedette - Nom commun","0","0",NULL),
("","151","Vedette - Nom géographique","Vedette - Nom géographique","0","0",NULL),
("","155","Vedette - Terme de genre/forme","Vedette - Terme de genre/forme","0","0",NULL),
("","180","Vedette - Subdivision générale","Vedette - Subdivision générale","0","0",NULL),
("","181","Vedette - Subdivision géographique","Vedette - Subdivision géographique","0","0",NULL),
("","182","Vedette - Subdivision chronologique","Vedette - Subdivision chronologique","0","0",NULL),
("","185","Vedette - Subdivision de forme","Vedette - Subdivision de forme","0","0",NULL),
("","260","Renvoi complexe « voir » - Vedette-matière","Renvoi complexe « voir » - Vedette-matière","1","0",NULL),
("","360","Renvoi complexe « voir aussi » - Vedettes-matières","Renvoi complexe « voir aussi » - Vedettes-matières","1","0",NULL),
("","388","TIME PERIOD OF CREATION","TIME PERIOD OF CREATION","1","0",NULL),
("","400","Rappel de renvoi « voir » - Nom de personne","Rappel de renvoi « voir » - Nom de personne","1","0",NULL),
("","410","Rappel de renvoi « voir » - Nom de collectivité","Rappel de renvoi « voir » - Nom de collectivité","1","0",NULL),
("","411","Rappel de renvoi « voir » - Nom de réunion","Rappel de renvoi « voir » - Nom de réunion","1","0",NULL),
("","430","Rappel de renvoi « voir » - Titre uniforme","Rappel de renvoi « voir » - Titre uniforme","1","0",NULL),
("","448","Rappel de renvoi « voir » - Terme chronologique","Rappel de renvoi « voir » - Terme chronologique","1","0",NULL),
("","450","Rappel de renvoi « voir » - Nom commun","Rappel de renvoi « voir » - Nom commun","1","0",NULL),
("","451","Rappel de renvoi « voir » - Nom géographique","Rappel de renvoi « voir » - Nom géographique","1","0",NULL),
("","455","Rappel de renvoi « voir » - Terme de genre/forme","Rappel de renvoi « voir » - Terme de genre/forme","1","0",NULL),
("","480","Rappel de renvoi « voir » - Subdivision générale","Rappel de renvoi « voir » - Subdivision générale","1","0",NULL),
("","481","Rappel de renvoi « voir » - Subdivision géographique","Rappel de renvoi « voir » - Subdivision géographique","1","0",NULL),
("","482","Rappel de renvoi « voir » - Subdivision chronologique","Rappel de renvoi « voir » - Subdivision chronologique","1","0",NULL),
("","485","Rappel de renvoi « voir » - Subdivision de forme","Rappel de renvoi « voir » - Subdivision de forme","1","0",NULL),
("","500","Rappel de renvoi « voir aussi » - Nom de personne","Rappel de renvoi « voir aussi » - Nom de personne","1","0",NULL),
("","510","Rappel de renvoi « voir aussi » - Nom de collectivité","Rappel de renvoi « voir aussi » - Nom de collectivité","1","0",NULL),
("","511","Rappel de renvoi « voir aussi » - Nom de réunion","Rappel de renvoi « voir aussi » - Nom de réunion","1","0",NULL),
("","530","Rappel de renvoi « voir aussi » - Titre uniforme","Rappel de renvoi « voir aussi » - Titre uniforme","1","0",NULL),
("","548","Rappel de renvoi « voir aussi » - Terme chronologique","Rappel de renvoi « voir aussi » - Terme chronologique","1","0",NULL),
("","550","Rappel de renvoi « voir aussi » - Nom commun","Rappel de renvoi « voir aussi » - Nom commun","1","0",NULL),
("","551","Rappel de renvoi « voir aussi » - Nom géographique","Rappel de renvoi « voir aussi » - Nom géographique","1","0",NULL),
("","555","Rappel de renvoi « voir aussi » - Terme de genre/forme","Rappel de renvoi « voir aussi » - Terme de genre/forme","1","0",NULL),
("","580","Rappel de renvoi « voir aussi » - Subdivision générale","Rappel de renvoi « voir aussi » - Subdivision générale","1","0",NULL),
("","581","Rappel de renvoi « voir aussi » - Subdivision géographique","Rappel de renvoi « voir aussi » - Subdivision géographique","1","0",NULL),
("","582","Rappel de renvoi « voir aussi » - Subdivision chronologique","Rappel de renvoi « voir aussi » - Subdivision chronologique","1","0",NULL),
("","585","Rappel de renvoi « voir aussi » - Subdivision de forme","Rappel de renvoi « voir aussi » - Subdivision de forme","1","0",NULL),
("","640","Dates de publication et/ou indication séquentielle de collection","Dates de publication et/ou indication séquentielle de collection","1","0",NULL),
("","641","Particularités de numérotation de collection","Particularités de numérotation de collection","1","0",NULL),
("","642","Exemple de numérotation de collection","Exemple de numérotation de collection","1","0",NULL),
("","643","Lieu et éditeur de la collection/organisme de publication","Lieu et éditeur de la collection/organisme de publication","1","0",NULL),
("","644","Usage en matière d'analyse de collection","Usage en matière d'analyse de collection","1","0",NULL),
("","645","Usage en matière de rappel de collection","Usage en matière de rappel de collection","1","0",NULL),
("","646","Usage en matière de classification de collection","Usage en matière de classification de collection","1","0",NULL),
("","663","Renvoi complexe « voir aussi » - Vedette de nom","Renvoi complexe « voir aussi » - Vedette de nom","0","0",NULL),
("","664","Renvoi complexe « voir » - Vedette de nom","Renvoi complexe « voir » - Vedette de nom","0","0",NULL),
("","665","Renvoi historique","Renvoi historique","0","0",NULL),
("","666","Renvoi explicatif général - Vedette de nom","Renvoi explicatif général - Vedette de nom","0","0",NULL),
("","667","Note générale non destinée au public","Note générale non destinée au public","1","0",NULL),
("","670","Source des données","Source des données","1","0",NULL),
("","675","Source des données non trouvée","Source des données non trouvée","0","0",NULL),
("","678","Données biographiques ou historiques","Données biographiques ou historiques","1","0",NULL),
("","680","Note générale destinée au public","Note générale destinée au public","1","0",NULL),
("","681","Note de rappel d'exemple de vedette-matière","Note de rappel d'exemple de vedette-matière","1","0",NULL),
("","682","Renseignements sur les vedettes supprimées","Renseignements sur les vedettes supprimées","0","0",NULL),
("","683","Note d'application historique","Note d'application historique","1","0",NULL),
("","688","Note d'application historique","Note d'application historique","1","0",NULL),
("","700","Liaison des vedettes établies - Nom de personne","Liaison des vedettes établies - Nom de personne","1","0",NULL),
("","710","Liaison des vedettes établies - Nom de collectivité","Liaison des vedettes établies - Nom de collectivité","1","0",NULL),
("","711","Liaison des vedettes établies - Nom de réunion","Liaison des vedettes établies - Nom de réunion","1","0",NULL),
("","730","Liaison des vedettes établies - Titre uniforme","Liaison des vedettes établies - Titre uniforme","1","0",NULL),
("","748","Liaison des vedettes établies - Terme chronologique","Liaison des vedettes établies - Terme chronologique","1","0",NULL),
("","750","Liaison des vedettes établies - Nom commun","Liaison des vedettes établies - Nom commun","1","0",NULL),
("","751","Liaison des vedettes établies - Nom géographique","Liaison des vedettes établies - Nom géographique","1","0",NULL),
("","755","Liaison des vedettes établies - Terme de genre/forme","Liaison des vedettes établies - Terme de genre/forme","1","0",NULL),
("","780","Liaison des vedettes de subdivision - Subdivision générale","Liaison des vedettes de subdivision - Subdivision générale","1","0",NULL),
("","781","Liaison des vedettes de subdivision - Subdivision géographique","Liaison des vedettes de subdivision - Subdivision géographique","1","0",NULL),
("","782","Liaison des vedettes de subdivision - Subdivision chronologique","Liaison des vedettes de subdivision - Subdivision chronologique","1","0",NULL),
("","785","Liaison des vedettes de subdivision - Subdivision de forme","Liaison des vedettes de subdivision - Subdivision de forme","1","0",NULL),
("","788","Données de liaison des vedettes complexes","Données de liaison des vedettes complexes","0","0",NULL),
("","856","Emplacement et accès électroniques","Emplacement et accès électroniques","1","0",NULL),
("","880","Graphie alternative","Graphie alternative","1","0",NULL),
("","942","Utilisation interne à Koha","Utilisation interne à Koha","0","1",NULL);

INSERT INTO `auth_subfield_structure` (`authtypecode`, `tagfield`, `tagsubfield`, `liblibrarian`, `libopac`, `repeatable`, `mandatory`, `tab`, `authorised_value`, `value_builder`, `seealso`, `isurl`, `hidden`, `linkid`, `kohafield`, `frameworkcode`, `defaultvalue`) VALUES

("","000","@","Champ de contrôle de longueur fixe","Champ de contrôle de longueur fixe","0","1","0",NULL,"marc21_leader_authorities.pl",NULL,"0","0","0","","",NULL),
("","001","@","Numéro de contrôle","Numéro de contrôle","0","0","0",NULL,NULL,NULL,"0","0","0","auth_header.authid","",NULL),
("","003","@","Numéro de contrôle","Numéro de contrôle","0","1","0",NULL,"marc21_field_003.pl",NULL,"0","0","0","","",NULL),
("","005","@","Numéro de contrôle","Numéro de contrôle","0","1","0",NULL,"marc21_field_005.pl",NULL,"0","0","0","","",NULL),
("","008","@","Champ de contrôle de longueur fixe","Champ de contrôle de longueur fixe","0","1","0",NULL,"marc21_field_008_authorities.pl",NULL,"0","0","0","","",NULL),
("","010","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","010","a","Numéro de contrôle de la LC","Numéro de contrôle de la LC","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","010","z","Numéro de contrôle de la LC annulé/invalide","Numéro de contrôle de la LC annulé/invalide","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","014","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","014","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","014","a","Numéro de contrôle d'une notice bibliographique associée","Numéro de contrôle d'une notice bibliographique associée","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","016","2","Source","Source","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","016","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","016","a","Numéro de contrôle de la notice","Numéro de contrôle de la notice","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","016","z","Numéro de contrôle annulé ou invalide","Numéro de contrôle annulé ou invalide","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","020","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","020","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","020","a","Numéro international normalisé des livres","Numéro international normalisé des livres","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","020","c","Modalités d'acquisition","Modalités d'acquisition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","020","q","Qualifying information","Qualifying information","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","020","z","Modalités d'acquisition","Modalités d'acquisition","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","022","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","022","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","022","a","Numéro international normalisé des publications en série","Numéro international normalisé des publications en série","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","022","y","ISSN incorrect","ISSN incorrect","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","022","z","ISSN annulé","ISSN annulé","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","024","2","Source du numéro ou du code","Source du numéro ou du code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","024","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","024","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","024","a","Standard number or code","Standard number or code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","024","c","Modalités d'acquisition","Modalités d'acquisition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","024","d","Autres codes suivant le numéro ou code normalisé","Autres codes suivant le numéro ou code normalisé","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","024","q","Qualifying information","Qualifying information","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","024","z","Numéro ou code normalisé annulé ou invalide","Numéro ou code normalisé annulé ou invalide","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","2","Système d'encodage","Système d'encodage","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","a","Numéro de l'œuvre","Numéro de l'œuvre","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","b","Numéro du mouvement","Numéro du mouvement","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","c","Numéro de l'extrait","Numéro de l'extrait","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","d","Titre ou en-tête","Titre ou en-tête","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","e","Rôle","Rôle","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","g","Clé","Clé","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","m","Voix ou instrument","Voix ou instrument","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","n","Armature","Armature","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","o","Indication de la mesure","Indication de la mesure","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","p","Notation musicale","Notation musicale","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","q","Note générale","Note générale","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","r","Tonalité ou mode","Tonalité ou mode","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","s","Note codée concernant la validité","Note codée concernant la validité","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","t","Incipit du texte","Incipit du texte","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","031","u","Identificateur de ressource uniforme","Identificateur de ressource uniforme","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","2","Source","Source","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","d","Coordonnées - longitude la plus à l'ouest","Coordonnées - longitude la plus à l'ouest","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","e","Coordonnées - longitude la plus à l'est","Coordonnées - longitude la plus à l'est","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","f","Coordonnées - latitude la plus au nord","Coordonnées - latitude la plus au nord","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","g","Coordonnées - latitude la plus au sud","Coordonnées - latitude la plus au sud","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","j","Déclinaison - limite septentrionale","Déclinaison - limite septentrionale","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","k","Déclinaison - limite méridionale","Déclinaison - limite méridionale","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","m","Ascension droite - limites orientales","Ascension droite - limites orientales","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","n","Ascension droite - limites occidentales","Ascension droite - limites occidentales","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","p","Équinoxe","Équinoxe","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","r","Distance de la Terre","Distance de la Terre","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","s","Latitude sur l'anneau G","Latitude sur l'anneau G","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","t","Longitude sur l'anneau G","Longitude sur l'anneau G","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","x","Date de début","Date de début","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","y","Date de fin","Date de fin","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","034","z","Nom du corps céleste","Nom du corps céleste","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","035","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","035","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","035","a","Numéro de contrôle de système","Numéro de contrôle de système","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","035","z","Numéro de contrôle de système annulé/invalide","Numéro de contrôle de système annulé/invalide","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","040","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","040","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","040","a","Organisme qui a effectué le catalogage original","Organisme qui a effectué le catalogage original","0","1","0",NULL,"marc21_field_003.pl",NULL,"0","0","0","","",NULL),
("","040","b","Code de la langue utilisée dans le catalogage","Code de la langue utilisée dans le catalogage","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","040","c","Organisme qui a effectué la transcription","Organisme qui a effectué la transcription","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","040","d","Organisme qui a effectué la modification","Organisme qui a effectué la modification","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","040","e","Noms des règles de description","Noms des règles de description","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","040","f","Règles utilisées pour les vedettes-matières ou les thésaurus","Règles utilisées pour les vedettes-matières ou les thésaurus","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","042","a","Code d'authenticité","Code d'authenticité","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","043","2","Source du code local","Source du code local","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","043","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","043","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","043","a","Code d'aire géographique","Code d'aire géographique","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","043","b","Code d'aire géographique local","Code d'aire géographique local","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","043","c","Code ISO","Code ISO","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","045","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","045","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","045","a","Code de la période de temps","Code de la période de temps","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","045","b","Période de temps structurée : de 9999 avant J.-C. et après J.C.","Période de temps structurée : de 9999 avant J.-C. et après J.C.","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","045","c","Période de temps structurée : antérieure à 9999 avant J.-C.","Période de temps structurée : antérieure à 9999 avant J.-C.","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","050","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","050","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","050","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","050","a","Indice de classification","Indice de classification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","050","b","Item number","Item number","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","050","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","052","2","Source du code","Source du code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","052","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","052","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","052","a","Geographic classification area code","Geographic classification area code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","052","b","Code de classification de la subdivision d'aire géographique","Code de classification de la subdivision d'aire géographique","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","052","d","Nom de lieu habité","Nom de lieu habité","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","053","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","053","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","053","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","053","a","Indice de classification unique ou premier indice de classification d'une série","Indice de classification unique ou premier indice de classification d'une série","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","053","b","Dernier numéro de classification d'une série de numéros","Dernier numéro de classification d'une série de numéros","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","053","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","055","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","055","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","055","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","055","a","Indice de classification","Indice de classification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","055","b","Item number","Item number","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","055","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","058","5","Library to which class number applies","Library to which class number applies","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","058","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","058","a","LC classification number--Single number or beginning number of a range","LC classification number--Single number or beginning number of a range","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","058","b","LC classification number--End number of a range","LC classification number--End number of a range","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","058","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","060","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","060","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","060","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","060","a","Indice de classification","Indice de classification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","060","b","Item number","Item number","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","060","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","063","a","NLM classification number--Single number or beginning number of a range","NLM classification number--Single number or beginning number of a range","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","063","b","NLM classification number--End number of a range","NLM classification number--End number of a range","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","063","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","065","2","Source du code","Source du code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","065","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","065","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","065","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","065","a","Classification number element--single number or beginning of span","Classification number element--single number or beginning of span","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","065","b","Dernier numéro de classification d'une série de numéros","Dernier numéro de classification d'une série de numéros","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","065","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","066","a","Jeu de caractères primaire G0","Jeu de caractères primaire G0","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","066","b","Jeu de caractères primaire G1","Jeu de caractères primaire G1","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","066","c","Jeu de caractères alternatif G0 ou GI","Jeu de caractères alternatif G0 ou GI","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","068","5","Library to which class number applies","Library to which class number applies","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","068","a","NLM classification number--Single number or beginning number of a range","NLM classification number--Single number or beginning number of a range","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","068","b","NLM classification number--End number of a range","NLM classification number--End number of a range","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","068","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","070","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","070","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","070","a","Indice de classification","Indice de classification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","070","b","Item number","Item number","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","070","d","Volumes/dates auxquels s'applique la cote","Volumes/dates auxquels s'applique la cote","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","072","2","Source du code","Source du code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","072","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","072","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","072","a","Code de catégorie de sujets","Code de catégorie de sujets","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","072","x","Subdivision de code de catégorie de sujets","Subdivision de code de catégorie de sujets","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","073","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","073","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","073","a","Usage de la subdivision","Usage de la subdivision","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","073","z","Code source","Code source","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","082","2","Numéro d'édition","Numéro d'édition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","082","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","082","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","082","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","082","a","Indice de classification","Indice de classification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","082","b","Item number","Item number","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","082","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","083","2","Numéro d'édition","Numéro d'édition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","083","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","083","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","083","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","083","a","Indice de classification unique ou premier indice de classification d'une série","Indice de classification unique ou premier indice de classification d'une série","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","083","b","Dernier numéro de classification d'une série de numéros","Dernier numéro de classification d'une série de numéros","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","083","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","083","z","Numéro de la table d'identification","Numéro de la table d'identification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","084","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","084","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","084","a","Classification scheme code","Classification scheme code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","084","b","Edition title","Edition title","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","084","c","Edition identifier","Edition identifier","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","084","d","Source edition identifier","Source edition identifier","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","084","e","Language code","Language code","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","084","f","Authorization","Authorization","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","084","n","Variations","Variations","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","086","2","Source du code","Source du code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","086","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","086","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","086","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","086","a","Cote","Cote","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","086","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","086","z","Cote annulée ou invalide","Cote annulée ou invalide","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","087","2","Source du code","Source du code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","087","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","087","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","087","a","Indice de classification unique ou premier indice de classification d'une série","Indice de classification unique ou premier indice de classification d'une série","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","087","b","Dernier numéro de classification d'une série de numéros","Dernier numéro de classification d'une série de numéros","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","087","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","088","a","Document shelving number (CODOC)","Document shelving number (CODOC)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","2","Source du code","Source du code","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","a","Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)","Call number ; Classification number (OCLC) (R) ; Classification number, CALL (RLIN) (NR)","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","b","Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)","Item number ; Local cutter number (OCLC) ; Book number/undivided call number, CALL (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","e","Feature heading (OCLC)","Feature heading (OCLC)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","f","Filing suffix (OCLC) ; Footnote, FNT (RLIN)","Filing suffix (OCLC) ; Footnote, FNT (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","h","Output transaction history, HST (RLIN)","Output transaction history, HST (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","i","Output transaction instruction, INS (RLIN)","Output transaction instruction, INS (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","l","Extra card control statement, EXT (RLIN)","Extra card control statement, EXT (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","n","Additional local notes, ANT (RLIN)","Additional local notes, ANT (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","p","Pathfinder code, PTH (RLIN)","Pathfinder code, PTH (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","t","Field suppresion, FSP (RLIN)","Field suppresion, FSP (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","v","Volumes, VOL (RLIN)","Volumes, VOL (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","y","Date, VOL (RLIN)","Date, VOL (RLIN)","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","090","z","Cote annulée ou invalide","Cote annulée ou invalide","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","091","2","Numéro d'édition","Numéro d'édition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","091","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","091","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","091","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","091","a","Indice de classification unique ou premier indice de classification d'une série","Indice de classification unique ou premier indice de classification d'une série","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","091","b","Dernier numéro de classification d'une série de numéros","Dernier numéro de classification d'une série de numéros","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","091","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","091","z","Numéro de la table d'identification","Numéro de la table d'identification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","092","2","Numéro d'édition","Numéro d'édition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","092","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","092","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","092","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","092","a","Indice de classification","Indice de classification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","092","b","Item number","Item number","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","092","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","092","e","Feature heading","Feature heading","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","092","f","Filing suffix","Filing suffix","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","093","2","Numéro d'édition","Numéro d'édition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","093","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","093","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","093","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","093","a","Indice de classification unique ou premier indice de classification d'une série","Indice de classification unique ou premier indice de classification d'une série","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","093","b","Dernier numéro de classification d'une série de numéros","Dernier numéro de classification d'une série de numéros","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","093","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","093","z","Numéro de la table d'identification","Numéro de la table d'identification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","096","2","Numéro d'édition","Numéro d'édition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","096","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","096","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","096","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","096","a","Indice de classification","Indice de classification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","096","b","Item number","Item number","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","096","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","096","e","Feature heading","Feature heading","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","096","f","Filing suffix","Filing suffix","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","097","2","Numéro d'édition","Numéro d'édition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","097","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","097","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","097","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","097","a","Indice de classification unique ou premier indice de classification d'une série","Indice de classification unique ou premier indice de classification d'une série","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","097","b","Dernier numéro de classification d'une série de numéros","Dernier numéro de classification d'une série de numéros","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","097","c","Terme explicatif","Terme explicatif","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","097","z","Numéro de la table d'identification","Numéro de la table d'identification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","098","2","Numéro d'édition","Numéro d'édition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","098","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","098","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","098","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","098","a","Call number based on other classification scheme","Call number based on other classification scheme","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","098","b","Item number","Item number","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","098","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","098","e","Feature heading","Feature heading","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","098","f","Filing suffix","Filing suffix","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","099","2","Numéro d'édition","Numéro d'édition","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","099","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","099","6","Liaison","Liaison","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","099","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","099","a","Indice de classification","Indice de classification","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","099","b","Item number","Item number","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","099","d","Volumes/dates to which call number applies","Volumes/dates to which call number applies","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","099","e","Feature heading","Feature heading","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","099","f","Filing suffix","Filing suffix","0","0","0",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","a","Nom de personne","Nom de personne","0","0","1",NULL,NULL,"'100b','100c','100q','100d','100t','100o','100m','100r','100s','100k','100n','100p','100g','100l','100f','100h','100x','100z','100y','100v'","0","0","0","","",NULL),
("","100","b","Numérotation","Numérotation","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","c","Titres et autres qualificatifs associés au nom","Titres et autres qualificatifs associés au nom","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","d","Dates associées au nom","Dates associées au nom","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","e","Relation","Relation","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","f","Date du document","Date du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","g","Renseignements divers","Renseignements divers","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","h","Indication générale du genre de document","Indication générale du genre de document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","j","Qualificatif d'attribution","Qualificatif d'attribution","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","k","Sous-vedette de forme","Sous-vedette de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","l","Langue du document","Langue du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","n","Numéro de la partie/section du document","Numéro de la partie/section du document","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","q","Forme complète du nom","Forme complète du nom","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","r","Tonalité de la musique","Tonalité de la musique","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","s","Version","Version","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","t","Titre du document","Titre du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","100","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","a","Nom de collectivité ou nom de lieu comme élément de classement","Nom de collectivité ou nom de lieu comme élément de classement","0","0","1",NULL,NULL,"'110b','110c','110d','110t','110o','110m','110r','110s','110k','110n','110p','110g','110l','110f','110h','110x','110z','110y','110v'","0","0","0","","",NULL),
("","110","b","Collectivité subordonnée","Collectivité subordonnée","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","c","Lieu de réunion","Lieu de réunion","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","d","Date de réunion ou de signature du traité","Date de réunion ou de signature du traité","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","e","Relation","Relation","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","f","Date du document","Date du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","g","Renseignements divers","Renseignements divers","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","h","Indication générale du genre de document","Indication générale du genre de document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","k","Sous-vedette de forme","Sous-vedette de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","l","Langue du document","Langue du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","n","Numéro de la partie/section/réunion","Numéro de la partie/section/réunion","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","r","Tonalité de la musique","Tonalité de la musique","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","s","Version","Version","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","t","Titre du document","Titre du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","110","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","a","Nom de réunion ou nom de lieu comme élément de classement","Nom de réunion ou nom de lieu comme élément de classement","0","0","1",NULL,NULL,"'111e','111c','111d','111t','111s','111k','111n','111p','111g','111l','111f','111h','111x','111z','111y','111v'","0","0","0","","",NULL),
("","111","b","Number [OBSOLETE]","Number [OBSOLETE]","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","c","Lieu de réunion","Lieu de réunion","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","d","Date de réunion","Date de réunion","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","e","Subordinate unit","Subordinate unit","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","f","Date du document","Date du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","g","Renseignements divers","Renseignements divers","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","h","Indication générale du genre de document","Indication générale du genre de document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","j","Relator term","Relator term","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","k","Sous-vedette de forme","Sous-vedette de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","l","Langue du document","Langue du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","n","Numéro de la partie/section/réunion","Numéro de la partie/section/réunion","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","q","Nom de la conférence suivant un nom de lieu comme élément de classement","Nom de la conférence suivant un nom de lieu comme élément de classement","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","s","Version","Version","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","t","Titre du document","Titre du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","111","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","a","Titre uniforme","Titre uniforme","0","0","1",NULL,NULL,"'130o','130m','130r','130s','130d','130k','130n','130p','130g','130l','130f','130h','130t','130x','130z','130y','130v'","0","0","0","","",NULL),
("","130","d","Date de signature du traité","Date de signature du traité","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","f","Date du document","Date du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","g","Renseignements divers","Renseignements divers","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","h","Indication générale du genre de document","Indication générale du genre de document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","k","Sous-vedette de forme","Sous-vedette de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","l","Langue du document","Langue du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","n","Numéro de la partie/section du document","Numéro de la partie/section du document","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","r","Tonalité de la musique","Tonalité de la musique","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","s","Version","Version","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","t","Titre du document","Titre du document","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","130","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","148","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","148","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","148","a","Terme chronologique","Terme chronologique","0","0","1",NULL,NULL,"'148y','148x','148z','148v'","0","0","0","","",NULL),
("","148","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","148","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","148","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","148","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","150","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","150","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","150","a","Vedette de sujet ou vedette comportant un nom géographique","Vedette de sujet ou vedette comportant un nom géographique","0","0","1",NULL,NULL,"'150x','150z','150y','150v'","0","0","0","","",NULL),
("","150","b","Vedette de sujet débutant par un nom géographique","Vedette de sujet débutant par un nom géographique","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","150","g","Miscellaneous information","Miscellaneous information","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","150","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","150","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","150","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","150","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","151","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","151","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","151","a","Nom géographique","Nom géographique","0","0","1",NULL,NULL,"'151z','151x','151y','151v'","0","0","0","","",NULL),
("","151","b","Name following place as an entry element {OBSOLETE]","Name following place as an entry element {OBSOLETE]","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","151","g","Miscellaneous information","Miscellaneous information","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","151","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","151","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","151","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","151","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","153","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","153","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","153","a","Classification number--Single number or beginning number of span","Classification number--Single number or beginning number of span","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","153","c","Classification number--Ending number of span","Classification number--Ending number of span","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","153","h","Caption hierarchy","Caption hierarchy","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","153","j","Caption","Caption","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","153","k","Summary number span caption hierarchy","Summary number span caption hierarchy","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","153","z","Table identification","Table identification","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","154","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","154","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","154","a","General explanatory index term","General explanatory index term","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","154","b","General explanatory index term--Succeeding level","General explanatory index term--Succeeding level","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","154","f","Schedule identification","Schedule identification","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","155","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","155","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","155","a","Terme de genre/forme","Terme de genre/forme","0","0","1",NULL,NULL,"'155v','155x','155z','155y'","0","0","0","","",NULL),
("","155","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","155","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","155","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","155","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","180","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","180","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","180","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","180","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","180","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","180","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","181","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","181","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","181","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","181","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","181","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","181","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","182","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","182","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","182","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","182","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","182","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","182","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","185","6","Liaison","Liaison","0","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","185","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","185","v","Subdivision de forme","Subdivision de forme","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","185","x","Subdivision générale","Subdivision générale","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","185","y","Subdivision chronologique","Subdivision chronologique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","185","z","Subdivision géographique","Subdivision géographique","1","0","1",NULL,NULL,NULL,"0","0","0","","",NULL),
("","253","6","Liaison","Liaison","0","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","253","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","253","a","Classification number referred to--Single number or beginning number of span","Classification number referred to--Single number or beginning number of span","1","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","253","c","Classification number referred to--Ending number of span","Classification number referred to--Ending number of span","1","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","253","i","Texte explicatif","Texte explicatif","1","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","253","y","Table identification--Schedule [OBSOLETE]","Table identification--Schedule [OBSOLETE]","0","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","253","z","Table identification","Table identification","1","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","260","6","Liaison","Liaison","0","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","260","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","260","a","Vedette d'arrivée du renvoi","Vedette d'arrivée du renvoi","1","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","260","i","Texte explicatif","Texte explicatif","1","0","2",NULL,NULL,NULL,"0","0","0","","",NULL),
("","353","6","Liaison","Liaison","0","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","353","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","353","a","Classification number referred to--Single number or beginning number of span","Classification number referred to--Single number or beginning number of span","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","353","c","Classification number referred to--Ending number of span","Classification number referred to--Ending number of span","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","353","i","Texte explicatif","Texte explicatif","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","353","y","Table identification--Schedule [OBSOLETE]","Table identification--Schedule [OBSOLETE]","0","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","353","z","Table identification","Table identification","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","360","6","Liaison","Liaison","0","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","360","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","360","a","Vedette d'arrivée du renvoi","Vedette d'arrivée du renvoi","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","360","i","Texte explicatif","Texte explicatif","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","388","0","Authority record control number or standard number","Authority record control number or standard number","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","388","2","Source of term","Source of term","0","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","388","3","Materials specified","Materials specified","0","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","388","6","Linkage","Linkage","0","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","388","8","Field link and sequence number","Field link and sequence number","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","388","a","Time period of creation term","Time period of creation term","1","0","3",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","9","9 (RLIN)","9 (RLIN)","0","0","4",NULL,NULL,NULL,"0","1","0","","",NULL),
("","400","a","Nom de personne","Nom de personne","0","0","4",NULL,NULL,"'400b','400c','400q','400d','400t','400o','400m','400r','400s','400k','400n','400p','400g','400l','400f','400h','400x','400z','400y','400v'","0","0","0","","PERSO_NAME",NULL),
("","400","b","Numérotation","Numérotation","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","c","Titres et autres qualificatifs associés au nom","Titres et autres qualificatifs associés au nom","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","d","Dates associées au nom","Dates associées au nom","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","e","Relation","Relation","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","f","Date du document","Date du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","g","Renseignements divers","Renseignements divers","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","h","Indication générale du genre de document","Indication générale du genre de document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","j","Qualificatif d'attribution","Qualificatif d'attribution","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","k","Sous-vedette de forme","Sous-vedette de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","l","Langue du document","Langue du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","n","Numéro de la partie/section du document","Numéro de la partie/section du document","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","q","Forme complète du nom","Forme complète du nom","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","r","Tonalité de la musique","Tonalité de la musique","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","s","Version","Version","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","t","Titre du document","Titre du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","400","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","9","9 (RLIN)","9 (RLIN)","0","0","4",NULL,NULL,NULL,"0","1","0","","",NULL),
("","410","a","Nom de collectivité ou nom de lieu comme élément de classement","Nom de collectivité ou nom de lieu comme élément de classement","0","0","4",NULL,NULL,"'410b','410c','410d','410t','410o','410m','410r','410s','410k','410n','410p','410g','410l','410f','410h','410x','410z','410y','410v'","0","0","0","","CORPO_NAME",NULL),
("","410","b","Collectivité subordonnée","Collectivité subordonnée","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","c","Lieu de réunion","Lieu de réunion","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","d","Date de réunion ou de signature du traité","Date de réunion ou de signature du traité","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","e","Relation","Relation","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","f","Date du document","Date du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","g","Renseignements divers","Renseignements divers","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","h","Indication générale du genre de document","Indication générale du genre de document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","k","Sous-vedette de forme","Sous-vedette de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","l","Langue du document","Langue du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","n","Numéro de la partie/section/réunion","Numéro de la partie/section/réunion","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","r","Tonalité de la musique","Tonalité de la musique","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","s","Version","Version","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","t","Titre du document","Titre du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","410","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","9","9 (RLIN)","9 (RLIN)","0","0","4",NULL,NULL,NULL,"0","1","0","","",NULL),
("","411","a","Nom de réunion ou nom de lieu comme élément de classement","Nom de réunion ou nom de lieu comme élément de classement","0","0","4",NULL,NULL,"'411e','411c','411d','411t','411s','411k','411n','411p','411g','411l','411f','411h','411x','411z','411y','411v'","0","0","0","","MEETI_NAME",NULL),
("","411","b","Number {OBSOLETE]","Number {OBSOLETE]","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","c","Lieu de réunion","Lieu de réunion","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","d","Date de réunion","Date de réunion","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","e","Subordinate unit","Subordinate unit","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","f","Date du document","Date du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","g","Renseignements divers","Renseignements divers","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","h","Indication générale du genre de document","Indication générale du genre de document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","k","Sous-vedette de forme","Sous-vedette de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","l","Langue du document","Langue du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","n","Numéro de la partie/section/réunion","Numéro de la partie/section/réunion","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","q","Nom de la conférence suivant un nom de lieu comme élément de classement","Nom de la conférence suivant un nom de lieu comme élément de classement","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","s","Version","Version","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","t","Titre du document","Titre du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","411","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","9","9 (RLIN)","9 (RLIN)","0","0","4",NULL,NULL,NULL,"0","1","0","","",NULL),
("","430","a","Titre uniforme","Titre uniforme","0","0","4",NULL,NULL,"'430o','430m','430r','430s','430d','430k','430n','430p','430g','430l','430f','430h','430t','430x','430z','430y','430v'","0","0","0","","UNIF_TITLE",NULL),
("","430","d","Date de signature du traité","Date de signature du traité","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","f","Date du document","Date du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","g","Renseignements divers","Renseignements divers","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","h","Indication générale du genre de document","Indication générale du genre de document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","k","Sous-vedette de forme","Sous-vedette de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","l","Langue du document","Langue du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","n","Numéro de la partie/section du document","Numéro de la partie/section du document","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","r","Tonalité de la musique","Tonalité de la musique","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","s","Version","Version","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","t","Titre du document","Titre du document","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","430","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","448","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","448","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","448","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","448","9","9 (RLIN)","9 (RLIN)","0","0","4",NULL,NULL,NULL,"0","1","0","","",NULL),
("","448","a","Terme chronologique","Terme chronologique","0","0","4",NULL,NULL,"'448y','448x','448z','448v'","0","0","0","","CHRON_TERM",NULL),
("","448","i","Reference instruction phrase","Reference instruction phrase","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","448","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","448","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","448","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","448","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","448","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","9","9 (RLIN)","9 (RLIN)","0","0","4",NULL,NULL,NULL,"0","1","0","","",NULL),
("","450","a","Vedette de sujet ou vedette comportant un nom géographique","Vedette de sujet ou vedette comportant un nom géographique","0","0","4",NULL,NULL,"'450x','450z','450y','450v'","0","0","0","","TOPIC_TERM",NULL),
("","450","b","Vedette de sujet débutant par un nom géographique","Vedette de sujet débutant par un nom géographique","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","g","Miscellaneous information","Miscellaneous information","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","450","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","9","9 (RLIN)","9 (RLIN)","0","0","4",NULL,NULL,NULL,"0","1","0","","",NULL),
("","451","a","Nom géographique","Nom géographique","0","0","4",NULL,NULL,"'451z','451x','451y','451v'","0","0","0","","GEOGR_NAME",NULL),
("","451","g","Miscellaneous information","Miscellaneous information","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","451","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","9","9 (RLIN)","9 (RLIN)","0","0","4",NULL,NULL,NULL,"0","1","0","","",NULL),
("","453","a","Classification number--Single number or beginning number of span","Classification number--Single number or beginning number of span","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","c","Classification element--Ending number of span","Classification element--Ending number of span","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","h","Caption hierarchy","Caption hierarchy","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","j","Caption","Caption","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","k","Summary number span caption hierarchy","Summary number span caption hierarchy","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","t","Topic","Topic","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","y","Table identification--Schedule [OBSOLETE]","Table identification--Schedule [OBSOLETE]","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","453","z","Table identification","Table identification","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","455","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","455","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","455","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","455","9","9 (RLIN)","9 (RLIN)","0","0","4",NULL,NULL,NULL,"0","1","0","","",NULL),
("","455","a","Terme de genre/forme","Terme de genre/forme","0","0","4",NULL,NULL,"'455v','455x','455z','455y'","0","0","0","","GENRE/FORM",NULL),
("","455","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","455","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","455","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","455","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","455","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","455","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","480","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","480","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","480","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","480","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","480","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","480","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","480","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","480","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","480","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","481","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","481","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","481","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","481","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","481","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","481","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","481","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","481","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","481","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","482","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","482","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","482","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","482","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","482","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","482","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","482","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","482","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","482","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","485","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","485","6","Liaison","Liaison","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","485","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","485","i","Reference instruction phrase","Reference instruction phrase","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","485","v","Subdivision de forme","Subdivision de forme","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","485","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","485","x","Subdivision générale","Subdivision générale","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","485","y","Subdivision chronologique","Subdivision chronologique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","485","z","Subdivision géographique","Subdivision géographique","1","0","4",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","9","9 (RLIN)","9 (RLIN)","0","0","5",NULL,NULL,NULL,"0","1","0","","",NULL),
("","500","a","Nom de personne","Nom de personne","0","0","5",NULL,NULL,"'500b','500c','500q','500d','500t','500o','500m','500r','500s','500k','500n','500p','500g','500l','500f','500h','500x','500z','500y','500v'","0","0","0","","PERSO_NAME",NULL),
("","500","b","Numérotation","Numérotation","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","c","Titres et autres qualificatifs associés au nom","Titres et autres qualificatifs associés au nom","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","d","Dates associées au nom","Dates associées au nom","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","e","Relation","Relation","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","f","Date du document","Date du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","g","Renseignements divers","Renseignements divers","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","h","Indication générale du genre de document","Indication générale du genre de document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","j","Qualificatif d'attribution","Qualificatif d'attribution","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","k","Sous-vedette de forme","Sous-vedette de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","l","Langue du document","Langue du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","n","Numéro de la partie/section du document","Numéro de la partie/section du document","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","q","Forme complète du nom","Forme complète du nom","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","r","Tonalité de la musique","Tonalité de la musique","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","s","Version","Version","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","t","Titre du document","Titre du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","500","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","9","9 (RLIN)","9 (RLIN)","0","0","5",NULL,NULL,NULL,"0","1","0","","",NULL),
("","510","a","Nom de collectivité ou nom de lieu comme élément de classement","Nom de collectivité ou nom de lieu comme élément de classement","0","0","5",NULL,NULL,"'510b','510c','510d','510t','510o','510m','510r','510s','510k','510n','510p','510g','510l','510f','510h','510x','510z','510y','510v'","0","0","0","","CORPO_NAME",NULL),
("","510","b","Collectivité subordonnée","Collectivité subordonnée","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","c","Lieu de réunion","Lieu de réunion","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","d","Date de réunion ou de signature du traité","Date de réunion ou de signature du traité","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","e","Relation","Relation","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","f","Date du document","Date du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","g","Renseignements divers","Renseignements divers","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","h","Indication générale du genre de document","Indication générale du genre de document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","k","Sous-vedette de forme","Sous-vedette de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","l","Langue du document","Langue du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","n","Numéro de la partie/section/réunion","Numéro de la partie/section/réunion","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","r","Tonalité de la musique","Tonalité de la musique","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","s","Version","Version","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","t","Titre du document","Titre du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","510","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","9","9 (RLIN)","9 (RLIN)","0","0","5",NULL,NULL,NULL,"0","1","0","","",NULL),
("","511","a","Nom de réunion ou nom de lieu comme élément de classement","Nom de réunion ou nom de lieu comme élément de classement","0","0","5",NULL,NULL,"'511e','511c','511d','511t','511s','511k','511n','511p','511g','511l','511f','511h','511x','511z','511y','511v'","0","0","0","","MEETI_NAME",NULL),
("","511","c","Lieu de réunion","Lieu de réunion","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","d","Date de réunion","Date de réunion","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","e","Subordinate unit","Subordinate unit","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","f","Date du document","Date du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","g","Renseignements divers","Renseignements divers","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","h","Indication générale du genre de document","Indication générale du genre de document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","k","Sous-vedette de forme","Sous-vedette de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","l","Langue du document","Langue du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","n","Numéro de la partie/section/réunion","Numéro de la partie/section/réunion","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","q","Nom de la conférence suivant un nom de lieu comme élément de classement","Nom de la conférence suivant un nom de lieu comme élément de classement","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","s","Version","Version","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","t","Titre du document","Titre du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","511","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","9","9 (RLIN)","9 (RLIN)","0","0","5",NULL,NULL,NULL,"0","1","0","","",NULL),
("","530","a","Titre uniforme","Titre uniforme","0","0","5",NULL,NULL,"'530o','530m','530r','530s','530d','530k','530n','530p','530g','530l','530f','530h','530t','530x','530z','530y','530v'","0","0","0","","UNIF_TITLE",NULL),
("","530","d","Date de signature du traité","Date de signature du traité","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","f","Date du document","Date du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","g","Renseignements divers","Renseignements divers","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","h","Indication générale du genre de document","Indication générale du genre de document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","k","Sous-vedette de forme","Sous-vedette de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","l","Langue du document","Langue du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","n","Numéro de la partie/section du document","Numéro de la partie/section du document","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","r","Tonalité de la musique","Tonalité de la musique","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","s","Version","Version","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","t","Titre du document","Titre du document","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","530","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","9","9 (RLIN)","9 (RLIN)","0","0","5",NULL,NULL,NULL,"0","1","0","","",NULL),
("","548","a","Terme chronologique","Terme chronologique","0","0","5",NULL,NULL,"'548y','548x','548z','548v'","0","0","0","","CHRON_TERM",NULL),
("","548","i","Reference instruction phrase","Reference instruction phrase","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","548","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","9","9 (RLIN)","9 (RLIN)","0","0","5",NULL,NULL,NULL,"0","1","0","","",NULL),
("","550","a","Vedette de sujet ou vedette comportant un nom géographique","Vedette de sujet ou vedette comportant un nom géographique","0","0","5",NULL,NULL,"'550x','550z','550y','550v'","0","0","0","","TOPIC_TERM",NULL),
("","550","b","Vedette de sujet débutant par un nom géographique","Vedette de sujet débutant par un nom géographique","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","g","Miscellaneous information","Miscellaneous information","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","550","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","9","9 (RLIN)","9 (RLIN)","0","0","5",NULL,NULL,NULL,"0","1","0","","",NULL),
("","551","a","Nom géographique","Nom géographique","0","0","5",NULL,NULL,"'551z','551x','551y','551v'","0","0","0","","GEOGR_NAME",NULL),
("","551","g","Miscellaneous information","Miscellaneous information","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","551","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","9","9 (RLIN)","9 (RLIN)","0","0","5",NULL,NULL,NULL,"0","1","0","","",NULL),
("","553","a","Classification number--Single number or beginning number of span","Classification number--Single number or beginning number of span","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","c","Classification number--Ending number of span","Classification number--Ending number of span","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","h","Caption hierarchy","Caption hierarchy","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","j","Caption","Caption","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","k","Summary number span caption hierarchy","Summary number span caption hierarchy","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","t","Topic","Topic","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","y","Table identification--Schedule [OBSOLETE]","Table identification--Schedule [OBSOLETE]","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","553","z","Table identification","Table identification","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","9","9 (RLIN)","9 (RLIN)","0","0","5",NULL,NULL,NULL,"0","1","0","","",NULL),
("","555","a","Terme de genre/forme","Terme de genre/forme","0","0","5",NULL,NULL,"'555v','555x','555z','555y'","0","0","0","","GENRE/FORM",NULL),
("","555","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","555","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","580","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","581","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","582","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","0","Record control number","Record control number","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","6","Liaison","Liaison","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","i","Reference instruction phrase","Reference instruction phrase","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","v","Subdivision de forme","Subdivision de forme","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","x","Subdivision générale","Subdivision générale","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","y","Subdivision chronologique","Subdivision chronologique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","585","z","Subdivision géographique","Subdivision géographique","1","0","5",NULL,NULL,NULL,"0","0","0","","",NULL),
("","640","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","640","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","640","a","Dates of publication and/or sequential designation","Dates of publication and/or sequential designation","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","640","z","Source d'information","Source d'information","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","641","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","641","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","641","a","Note sur les particularités de numérotation de la collection","Note sur les particularités de numérotation de la collection","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","641","z","Source d'information","Source d'information","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","642","5","Institution/exemplaire auquel s'applique la zone","Institution/exemplaire auquel s'applique la zone","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","642","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","642","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","642","a","Exemple de numérotation de collection","Exemple de numérotation de collection","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","642","d","Volumes/dates auxquels s'applique l'exemple de numérotation de collection","Volumes/dates auxquels s'applique l'exemple de numérotation de collection","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","643","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","643","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","643","a","Lieu","Lieu","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","643","b","Éditeur/organisme de publication","Éditeur/organisme de publication","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","643","d","Volumes/dates auxquels s'appliquent le lieu et l'éditeur ou l'organisme de publication","Volumes/dates auxquels s'appliquent le lieu et l'éditeur ou l'organisme de publication","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","644","5","Institution/exemplaire auquel s'applique la zone","Institution/exemplaire auquel s'applique la zone","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","644","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","644","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","644","a","Usage en matière d'analyse de collection","Usage en matière d'analyse de collection","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","644","b","Exceptions à l'usage en matière d'analyse de collection","Exceptions à l'usage en matière d'analyse de collection","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","644","d","Volumes/dates auxquels s'applique l'usage en matière d'analyse de collection","Volumes/dates auxquels s'applique l'usage en matière d'analyse de collection","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","645","5","Institution/exemplaire auquel s'applique la zone","Institution/exemplaire auquel s'applique la zone","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","645","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","645","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","645","a","Usage en matière de rappel de collection","Usage en matière de rappel de collection","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","645","d","Volumes/dates auxquels s'applique l'usage en matière de rappel de collection","Volumes/dates auxquels s'applique l'usage en matière de rappel de collection","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","646","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","646","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","646","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","646","a","Usage en matière de classification de collection","Usage en matière de classification de collection","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","646","d","Volumes/dates auxquels s'applique l'usage en matière de classification","Volumes/dates auxquels s'applique l'usage en matière de classification","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","663","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","663","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","663","a","Explanatory text","Explanatory text","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","663","b","Heading referred to","Heading referred to","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","663","t","Texte explicatif","Texte explicatif","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","664","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","664","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","664","a","Explanatory text","Explanatory text","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","664","b","Heading referred to","Heading referred to","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","664","t","Texte explicatif","Texte explicatif","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","665","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","665","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","665","a","Renvoi historique","Renvoi historique","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","666","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","666","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","666","a","Renvoi explicatif général","Renvoi explicatif général","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","667","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","667","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","667","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","667","a","Note générale non destinée au public","Note générale non destinée au public","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","668","a","Characters in nonroman alphabet","Characters in nonroman alphabet","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","670","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","670","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","670","a","Citation de la source","Citation de la source","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","670","b","Information trouvée","Information trouvée","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","670","u","Identificateur de ressource uniforme","Identificateur de ressource uniforme","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","671","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","671","a","Citation","Citation","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","675","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","675","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","675","a","Citation de la source","Citation de la source","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","676","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","676","a","Rule number(s) and additional information","Rule number(s) and additional information","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","678","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","678","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","678","a","Données biographiques ou historiques","Données biographiques ou historiques","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","678","b","Extension","Extension","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","678","u","Identificateur de ressource uniforme","Identificateur de ressource uniforme","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","680","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","680","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","680","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","680","a","Terme de vedette ou de subdivision","Terme de vedette ou de subdivision","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","680","c","Classification number--Ending number of span [CLASSIFICATION FORMAT]","Classification number--Ending number of span [CLASSIFICATION FORMAT]","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","680","i","Texte explicatif","Texte explicatif","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","680","z","Table identification","Table identification","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","681","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","681","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","681","a","Vedette-matière ou terme de subdivision","Vedette-matière ou terme de subdivision","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","681","c","Classification number--Ending number of span [CLASSIFICATION FORMAT]","Classification number--Ending number of span [CLASSIFICATION FORMAT]","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","681","i","Texte explicatif","Texte explicatif","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","681","z","Table identification","Table identification","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","682","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","682","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","682","a","Vedette de remplacement","Vedette de remplacement","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","682","i","Texte explicatif","Texte explicatif","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","683","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","683","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","683","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","683","a","Classification number--Single number or beginning number of span","Classification number--Single number or beginning number of span","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","683","c","Classification number--Ending number of span","Classification number--Ending number of span","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","683","i","Texte explicatif","Texte explicatif","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","683","p","Corresponding classification field","Corresponding classification field","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","683","y","Table identification--Schedule [OBSOLETE]","Table identification--Schedule [OBSOLETE]","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","683","z","Table identification","Table identification","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","684","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","684","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","684","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","684","a","Classification number--Single number or beginning number of span","Classification number--Single number or beginning number of span","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","684","c","Classification number--Ending number of span","Classification number--Ending number of span","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","684","i","Texte explicatif","Texte explicatif","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","684","j","Caption","Caption","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","684","z","Table identification","Table identification","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","685","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","685","a","Source consulted and information found","Source consulted and information found","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","686","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","686","a","Source consulted and information found","Source consulted and information found","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","687","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","687","a","Source consulted and information found","Source consulted and information found","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","688","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","688","6","Liaison","Liaison","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","688","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","688","a","Vedette de remplacement","Vedette de remplacement","0","0","6",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","3","Materials specified [CLASSIFICATION FORMAT]","Materials specified [CLASSIFICATION FORMAT]","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","a","Nom de personne","Nom de personne","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","b","Numérotation","Numérotation","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","c","Titres et autres qualificatifs associés au nom","Titres et autres qualificatifs associés au nom","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","d","Dates associées au nom","Dates associées au nom","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","e","Relation","Relation","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","f","Date du document","Date du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","g","Renseignements divers","Renseignements divers","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","h","Indication générale du genre de document","Indication générale du genre de document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","k","Attribution qualifier","Attribution qualifier","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","l","Langue du document","Langue du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","n","Numéro de la partie/section du document","Numéro de la partie/section du document","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","q","Forme complète du nom","Forme complète du nom","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","r","Tonalité de la musique","Tonalité de la musique","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","s","Version","Version","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","t","Titre du document","Titre du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","700","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","3","Materials specified [CLASSIFICATION FORMAT]","Materials specified [CLASSIFICATION FORMAT]","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","a","Nom de collectivité ou nom de lieu comme élément de classement","Nom de collectivité ou nom de lieu comme élément de classement","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","b","Collectivité subordonnée","Collectivité subordonnée","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","c","Lieu de réunion","Lieu de réunion","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","d","Date de réunion ou de signature du traité","Date de réunion ou de signature du traité","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","e","Relation","Relation","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","f","Date du document","Date du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","g","Renseignements divers","Renseignements divers","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","h","Indication générale du genre de document","Indication générale du genre de document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","k","Sous-vedette de forme","Sous-vedette de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","l","Langue du document","Langue du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","n","Numéro de la partie/section/réunion","Numéro de la partie/section/réunion","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","r","Tonalité de la musique","Tonalité de la musique","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","s","Version","Version","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","t","Titre du document","Titre du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","710","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","3","Materials specified","Materials specified","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","4","Relator code","Relator code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","a","Nom de réunion ou nom de lieu comme élément de classement","Nom de réunion ou nom de lieu comme élément de classement","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","c","Lieu de réunion","Lieu de réunion","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","d","Date de réunion","Date de réunion","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","e","Subordinate unit","Subordinate unit","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","f","Date du document","Date du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","g","Renseignements divers","Renseignements divers","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","h","Indication générale du genre de document","Indication générale du genre de document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","i","Texte explicatif","Texte explicatif","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","k","Sous-vedette de forme","Sous-vedette de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","l","Langue du document","Langue du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","n","Numéro de la partie/section/réunion","Numéro de la partie/section/réunion","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","p","Nom de la partie/section du document","Nom de la partie/section du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","q","Nom de la conférence suivant un nom de lieu comme élément de classement","Nom de la conférence suivant un nom de lieu comme élément de classement","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","s","Version","Version","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","t","Titre du document","Titre du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","711","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","3","Materials specified [CLASSIFICATION FORMAT]","Materials specified [CLASSIFICATION FORMAT]","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","a","Titre uniforme","Titre uniforme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","d","Date de signature du traité","Date de signature du traité","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","f","Date du document","Date du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","g","Renseignements divers","Renseignements divers","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","h","Indication générale du genre de document","Indication générale du genre de document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","k","Sous-vedette de forme","Sous-vedette de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","l","Langue du document","Langue du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","m","Médium d'exécution pour la musique","Médium d'exécution pour la musique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","n","Numéro de la partie/section du document","Numéro de la partie/section du document","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","o","Mention d'arrangement pour la musique","Mention d'arrangement pour la musique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","p","Nom de la partie/section du document","Nom de la partie/section du document","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","r","Tonalité de la musique","Tonalité de la musique","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","s","Version","Version","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","t","Titre du document","Titre du document","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","730","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","3","Materials specified [CLASSIFICATION FORMAT]","Materials specified [CLASSIFICATION FORMAT]","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","a","Terme chronologique","Terme chronologique","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","748","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","3","Materials specified [CLASSIFICATION FORMAT]","Materials specified [CLASSIFICATION FORMAT]","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","a","Vedette de sujet ou vedette comportant un nom géographique","Vedette de sujet ou vedette comportant un nom géographique","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","b","Vedette de sujet débutant par un nom géographique","Vedette de sujet débutant par un nom géographique","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","c","Location of event","Location of event","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","d","Active date","Active date","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","g","Miscellaneous information","Miscellaneous information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","750","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","3","Materials specified [CLASSIFICATION FORMAT]","Materials specified [CLASSIFICATION FORMAT]","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","a","Nom géographique","Nom géographique","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","g","Miscellaneous information","Miscellaneous information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","751","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","a","Index term","Index term","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","b","Index term--Succeeding level","Index term--Succeeding level","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","d","Index term referred from","Index term referred from","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","e","Example class number","Example class number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","i","Texte explicatif","Texte explicatif","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","s","See also reference term","See also reference term","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","t","See also reference term--Succeeding level","See also reference term--Succeeding level","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","u","Use reference term","Use reference term","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","753","v","Use reference term--Succeeding level","Use reference term--Succeeding level","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","3","Material specified","Material specified","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","a","Focus term","Focus term","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","b","Non-focus term","Non-focus term","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","c","Facet/hierarchy designation","Facet/hierarchy designation","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","754","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","a","Terme de genre/forme comme mot de classement","Terme de genre/forme comme mot de classement","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","755","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","a","Number where instructions are found--Single number or beginnning number of span","Number where instructions are found--Single number or beginnning number of span","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","b","Base number","Base number","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","c","Classification number--Ending number of span","Classification number--Ending number of span","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","d","Divided like number","Divided like number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","e","Example class number","Example class number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","f","Facet designator","Facet designator","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","i","Texte explicatif","Texte explicatif","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","n","Negative example class number","Negative example class number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","r","Root number","Root number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","x","Other classification number","Other classification number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","761","z","Table identification","Table identification","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","762","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","762","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","762","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","762","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","762","z","Table number","Table number","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","a","Classification number--Single number or beginning number of span","Classification number--Single number or beginning number of span","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","b","Base number","Base number","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","c","Classification number--Ending number of span","Classification number--Ending number of span","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","d","Divided like number","Divided like number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","e","Example class number","Example class number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","h","Caption hierarchy","Caption hierarchy","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","i","Texte explicatif","Texte explicatif","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","j","Caption","Caption","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","k","Summary number span caption hierarchy","Summary number span caption hierarchy","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","m","Manual note","Manual note","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","n","Number where instructions are found","Number where instructions are found","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","p","Corresponding classification field","Corresponding classification field","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","r","Root number","Root number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","s","See reference","See reference","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","x","Other classification number","Other classification number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","763","z","Table identification","Table identification","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","764","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","764","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","764","a","Rule number","Rule number","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","764","i","Texte explicatif","Texte explicatif","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","a","Number where instructions are found--Single number or beginning number of span","Number where instructions are found--Single number or beginning number of span","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","b","Base number","Base number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","c","Number where instructions are found--Ending number of span","Number where instructions are found--Ending number of span","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","f","Facet designator","Facet designator","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","r","Root number","Root number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","s","Digits added from classification number in schedule or external table","Digits added from classification number in schedule or external table","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","t","Digits added from internal subarrangement or add table","Digits added from internal subarrangement or add table","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","u","Number being analyzed","Number being analyzed","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","v","Number in internal subarrangement or add table where instructions are found","Number in internal subarrangement or add table where instructions are found","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","w","Table identification--Internal subarrangement or add table","Table identification--Internal subarrangement or add table","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","y","Table identification--Schedule [OBSOLETE]","Table identification--Schedule [OBSOLETE]","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","765","z","Table identification","Table identification","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","766","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","766","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","766","a","Secondary table of applicability","Secondary table of applicability","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","766","y","Type of division","Type of division","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","a","Classification number--Single number or beginning number of span","Classification number--Single number or beginning number of span","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","c","Classification number--Ending number of span","Classification number--Ending number of span","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","e","Example class number","Example class number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","i","Texte explicatif","Texte explicatif","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","j","Caption","Caption","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","n","Negative example class number","Negative example class number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","t","Topic used as example of citation and preference order instruction","Topic used as example of citation and preference order instruction","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","x","Exception to table of preference","Exception to table of preference","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","768","z","Numéro de la table d'identification","Numéro de la table d'identification","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","780","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","781","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","782","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","i","Relationship information","Relationship information","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","v","Subdivision de forme","Subdivision de forme","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","w","Sous-zone de contrôle","Sous-zone de contrôle","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","x","Subdivision générale","Subdivision générale","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","y","Subdivision chronologique","Subdivision chronologique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","785","z","Subdivision géographique","Subdivision géographique","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","788","0","Record control number","Record control number","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","788","2","Source de la vedette ou du terme","Source de la vedette ou du terme","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","788","4","Relationship code","Relationship code","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","788","5","Institution à laquelle s'applique la zone","Institution à laquelle s'applique la zone","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","788","6","Liaison","Liaison","0","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","788","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","788","a","Vedette d'arrivée du renvoi","Vedette d'arrivée du renvoi","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","788","i","Texte explicatif","Texte explicatif","1","0","7",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","2","Méthode d'accès","Méthode d'accès","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","3","Materials specified","Materials specified","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","6","Liaison","Liaison","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","8","Numéro de liaison de zone et de séquence","Numéro de liaison de zone et de séquence","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","a","Nom d'hôte","Nom d'hôte","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","b","Numéro d'accès","Numéro d'accès","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","c","Information sur la compression","Information sur la compression","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","d","Parcours","Parcours","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","f","Nom électronique","Nom électronique","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","h","Responsable du traitement de la demande","Responsable du traitement de la demande","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","i","Instruction","Instruction","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","j","Bits par seconde","Bits par seconde","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","k","Mot de passe","Mot de passe","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","l","Ouverture de la session","Ouverture de la session","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","m","Agent de liaison pour l'accès à l'information","Agent de liaison pour l'accès à l'information","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","n","Emplacement de l'ordinateur hôte","Emplacement de l'ordinateur hôte","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","o","Système d'exploitation","Système d'exploitation","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","p","Port","Port","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","q","Type de format électronique","Type de format électronique","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","r","Arrangement","Arrangement","0","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","s","Taille du fichier","Taille du fichier","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","t","Émulation du terminal","Émulation du terminal","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","u","Identificateur de ressource uniforme","Identificateur de ressource uniforme","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","v","Heures où la méthode d'accès est disponible","Heures où la méthode d'accès est disponible","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","w","Record control number","Record control number","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","x","Note non destinée au public","Note non destinée au public","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","y","Texte du lien","Texte du lien","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","856","z","Note destinée au public","Note destinée au public","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","0","0","0","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","1","1","1","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","2","2","2","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","3","3","3","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","4","4","4","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","5","5","5","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","6","6","6","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","7","7","7","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","8","8","8","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","9","9","9","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","a","a","a","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","b","b","b","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","c","c","c","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","d","d","d","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","e","e","e","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","f","f","f","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","g","g","g","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","h","h","h","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","i","i","i","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","j","j","j","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","k","k","k","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","l","l","l","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","m","m","m","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","n","n","n","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","o","o","o","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","p","p","p","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","q","q","q","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","r","r","r","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","s","s","s","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","t","t","t","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","u","u","u","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","v","v","v","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","w","w","w","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","x","x","x","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","y","y","y","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","880","z","z","z","1","0","8",NULL,NULL,NULL,"0","0","0","","",NULL),
("","942","a","Koha type d'authorite","Koha type d'authorite","0","1","9",NULL,NULL,NULL,"0","1","0","auth_header.authtypecode","",NULL);

-- ******************************************************

-- *******************************************************************
-- PERSONAL NAME AUTHORITY FIELDS/SUBFIELDS. XX0
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'PERSO_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ('110','111','130','148','150','151','155','162',
                     '180','181','182','185','034','640','641','642',
                     '643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'PERSO_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ('110','111','130','148','150','151','155','162',
                     '180','181','182','185','034','640','641','642',
                     '643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- CORPORATE NAME AUTHORITY FIELDS/SUBFIELDS. X10
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'CORPO_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','111','130','148','150','151','155','162',
                      '180','181','182','185','034','640','641','642',
                      '643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'CORPO_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','111','130','148','150','151','155','162',
                      '180','181','182','185','034','640','641','642',
                      '643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- MEETING NAME AUTHORITY FIELDS/SUBFIELDS. X11
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'MEETI_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','130','148','150','151','155','162',
                      '180','181','182','185','640','641','642','643',
                      '644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'MEETI_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','130','148','150','151','155','162',
                      '180','181','182','185','640','641','642','643',
                      '644','645','646');

-- ******************************************************

-- *******************************************************************
-- UNIFORM TITLE AUTHORITY FIELDS/SUBFIELDS. X30
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'UNIF_TITLE', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','148','150','151','155','162',
                      '180','181','182','185');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'UNIF_TITLE', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','148','150','151','155','162',
                      '180','181','182','185');

-- ******************************************************

-- *******************************************************************
-- CHRONOLOGICAL TERMS AUTHORITY FIELDS/SUBFIELDS. X48
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'CHRON_TERM', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','150','151','155','162',
                      '180','181','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'CHRON_TERM', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','150','151','155','162',
                      '180','181','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- TOPICAL TERMS AUTHORITY FIELDS/SUBFIELDS. X50
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'TOPIC_TERM', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','151','155','162',
                      '181','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'TOPIC_TERM', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','151','155','162',
                      '181','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- GEOGRAPHIC NAMES AUTHORITY FIELDS/SUBFIELDS. X51
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'GEOGR_NAME', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','155','162',
                      '180','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'GEOGR_NAME', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','155','162',
                      '180','182','185','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************

-- *******************************************************************
-- GENRE/FORM TERMS AUTHORITY FIELDS/SUBFIELDS. X55
-- *******************************************************************

-- copy from default auth framework except obsoleted tags

INSERT INTO auth_tag_structure (authtypecode, tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value)
    SELECT 'GENRE/FORM', tagfield, liblibrarian, libopac, repeatable, mandatory, authorised_value
    FROM auth_tag_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','151','162',
                      '180','181','182','014','020','022','031','640',
                      '641','642','643','644','645','646');

INSERT INTO auth_subfield_structure (authtypecode, tagfield, tagsubfield, liblibrarian, libopac, repeatable,
mandatory, tab, authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode)
    SELECT 'GENRE/FORM', tagfield, tagsubfield, liblibrarian, libopac, repeatable, mandatory, tab,
    authorised_value, value_builder, seealso, isurl, hidden, linkid, kohafield, frameworkcode
    FROM auth_subfield_structure
    WHERE authtypecode = '' AND
    tagfield NOT IN ( '058','063','068','084','088','140','143','153',
                      '154','253','353','453','553','668','671','676',
                      '684','685','686','687','753','754',
                      '761','763','764','765','766','768') AND
    tagfield NOT IN ( '100','110','111','130','148','150','151','162',
                      '180','181','182','014','020','022','031','640',
                      '641','642','643','644','645','646');

-- ******************************************************
